(***********************************************************************)
(*                                                                     *)
(* File:     TQPAT.m                                                   *)
(*                                                                     *)
(* Author:   Nikolai Zerf, zerf@particle.uni-karlsruhe.de              *)
(* Created:  Tue Apr 21, 2009                                          *)
(* Modified: Tue Apr 08, 2014                                          *)
(*                                                                     *)
(***********************************************************************)


(* Deriving Program Dir th*)
$TQPATProgramDir=StringReplace[$Input, {"/TQPAT.m" -> ""}];

(* Loading Config File *)
If[SyntaxQ[#],
   ToExpression[#];,
   Print["Couldn't find file TQPAT.config"];
   Abort[];]&@ StringReplace[Import[StringReplace[$Input, {".m" -> ".config"}],"Text"],{"Begin[\"TQPAT`Private`\"];"->"","End[];"->""}];

(*Loading LoopTools*)
(* Unfortunately LoopTools and SLAM use Global`A0 as variable.
  To avoid variable clash, we load LoopTools first,
  and save the implemented functions under different name.
  After that we can remove the Global variables and load SLAM *)
Install[$LoopToolsPath];
TQPAT`Private`DB0L = B0i[dbb0, ##1] &;
TQPAT`Private`B0L = B0i[bb0, ##1] &;
TQPAT`Private`C0L = C0i[cc0,##1]&;
DownValues[A0] /. A0 -> A0L /. RuleDelayed -> SetDelayed;
Remove[A0,B0,DB0,C0];
TQPAT`Private`LoopToolsNumercis = {TQPAT`Private`A0 -> TQPAT`Private`A0L, Global`B0 -> TQPAT`Private`B0L, Global`DB0 -> TQPAT`Private`DB0L, Global`C0 -> TQPAT`Private`C0L};


(* Loading SLAM in case its available *)
If[(Head[$SLAMPath] === String),
  If[(FileType[$SLAMPath] === File),
     Needs["SLAM`",$SLAMPath];,
     Print["Couldn't find SLAM.m at:",$SLAMPath];
     Abort[];
    ];
];

Remove[$SLAMPath,$LoopToolsPath,$FORTRANPath,$SPhenoPath,$SPhenoPatternInputFile,$TQPATProgramDir];
(*(* Avoiding colissions with LoopTools *)
Remove[A0];
Print[Names["*`A0"]];*)

Print[""];
Print["============================"];
Print["        TQPAT v1.02         "];
Print["      e+e- -> t tbar        "];
Print["      by Nikolai Zerf       "];
Print["============================"];

(*List of Global Variables *) 
{Special,Finite,Expanded,Divergent,Debug,Alfa, Alfa2, Alfas, CA, CA2, CB, CB2, CBA, Cha1, Cha2, CKM, CKMC, CW2(*, A0, B0, DB0, C0, D0*), EL, Gen1, IndexDelta, MA0, MA02, MB, MB2, MC, MC2, MCha, MCha1, MCha12, MCha2, MCha22, MD, MD2, ME, ME2, Mf, Mf2, MGl, MGl2, Mh0, Mh02, MH2, MHH, MHH2, MHp, MHp2, ML, ML2, MM, MM2, MNeu, MNeu1, MNeu12, MNeu2, MNeu22, MNeu3, MNeu32, MNeu4, MNeu42, MS, MS2, MSb1, MSb12, MSb2, MSb22, MSc1, MSc12, MSc2, MSc22, MSd1, MSd12, MSd2, MSd22, MSe1, MSe12, MSe2, MSe22, MSf, MSf2, MSl1, MSl12, MSl2, MSl22, MSm1, MSm12, MSm2, MSm22, MSne1, MSne12, MSne2, MSne22, MSnl1, MSnl12, MSnl2, MSnl22, MSnm1, MSnm12, MSnm2, MSnm22, MSs1, MSs12, MSs2, MSs22, MSt1, MSt12, MSt2, MSt22, MSu1, MSu12, MSu2, MSu22, MT, MT2, MU, MU2, MW2, MZ2, Neu1, Neu2, ON, SA, SA2, SB, SB2, SBA, Sfe1, Sfe2, SumOver, SW2, Tag, TB, TB2, UCha, UChaC, USf, USfC, VCha, VChaC, VSf, VSfC, ZNeu, ZNeuC,\[CapitalDelta],\[Sigma]};

BeginPackage["TQPAT`",{"Global`"}]

(*Internal Functions*)
ExpressPaVeFunctions::usage ="ExpressPaVeFunctions[Expression, Option] replaces all PaVe functions (A0, B0, DB0, C0, D0) in an expression with their analytic representation when available.\nPossible values for Option are:\nSpecial\nFinite\nExpanded\nDivergent\nDebug";
Contribution::usage="Contribution[ContributionContent, ContributionType] gives the analytic results for different amplitudes.\nAll existing combination of ContributionContent and ContributionType can be listed with DisplayListOfContributions[].\nMore details about the represented analytic results can be obtained with DisplayContributionInformation[].";
DeltaC::usage="DeltaC[ContributionContent, ContributionType] represents the analytic results for the relative correction of the cross section at s=4mt.\nIt is used as element of the ListOfContributions in the DoAllNumerics[ListOfContributions, DataSet(, Options)] function.\nAll existing combination of ContributionContent and ContributionType can be listed with DisplayListOfContributions[].\nMore details about the represented analytic results can be obtained with DisplayContributionInformation[].";
HeliL::usage="HeliL[ContributionContent, ContributionType] represents the analytic results for the left handed helicity amplitude at s=4mt.\nIt is used as element of the ListOfContributions in the DoAllNumerics[ListOfContributions, DataSet(, Options)] function.\nThe normalization of the helicity amplitude can be explored with Contribution[Born,TreeL]=heliL[Born,TreeL].\nAll existing combination of ContributionContent and ContributionType can be listed with DisplayListOfContributions[].\nMore details about the represented analytic expressions can be obtained with DisplayContributionInformation[].";
HeliR::usage="HeliR[ContributionContent, ContributionType] represents the analytic results for the right handed helicity amplitude at s=4mt.\nIt is used as element of the ListOfContributions in the DoAllNumerics[ListOfContributions, DataSet(, Options)] function.\nThe normalization of the helicity amplitude can be explored with Contribution[Born,TreeR]=heliR[Born,TreeR].\nAll existing combination of ContributionContent and ContributionType can be listed with DisplayListOfContributions[].\nMore details about the represented analytic expressions can be obtained with DisplayContributionInformation[].";
Direct::usage="Direct[Expression, NumericType] is used as element of the ListOfContributions in the DoAllNumerics[ListOfContributions, DataSet(, Options)] function./nWith it Expression is numerically evaluated using procedure NumericType./nThe following procedures are defined:\nSENumerics\ntVertexNumerics\neVertexNumerics\nBoxNumerics\nExtrapolationNumerics.";
SENumerics::usage="Numerical procedur for vector boson selfenergie corrections. It uses the built in one loop integral table."; 
tVertexNumerics::usage="Numerical procedur for top quark vertex corrections. It uses the built in one loop integral table."; 
eVertexNumerics::usage="Numerical procedur for electron vertex corrections. It needs LoopTools to evaluate the one loop integrals."; 
BoxNumerics::usage="Numerical procedur for box corrections. It uses the built in one loop integral table."; 
ExtrapolationNumerics::usage="Numerical procedur to extrapolate the relative corrections of the cross-section using the external FormCalc FORTRAN programs above the threshold.\n"; 


(*Functions*)
DrawLegend::usage="DrawLegend[LableList(,Options)] creates a plot legend from LableList in the format of a graphic object.\nThe output can be blended into a Plot using the Mathematica built-in function Show[Plot[...],DrawLegend[LableList(,Options)]].\nPossible Options and their default values can be obtained using: Options[DrawLegend].\nSimple example:\nLableListInput = {{Style[x^2, 20, Italic], {Red, Dotted, Thick}}, {Style[x, 20, Italic], {Blue, Dashed, Thick}}, {Style[x^(1/2), 20, Italic], {Darker[Green], Thick}}};\nShow[Plot[{x^2, x, Sqrt[x]}, {x, -1, 1}, PlotStyle -> {{Red, Dotted, Thick}, {Blue, Dashed, Thick}, {Darker[Green], Thick}}],\nDrawLegend[LableListInput, LegendFrame -> False, LegendFrameStyle -> {AbsoluteDashing[{1, 1}], Black}, LegendPosition -> {0.1, -1}, LegendSize -> {0.5, 0.8}, LayoutBoxes -> False, TextSpace -> 0.3, LineSpace -> 0.7, TextOffset -> {0.0, 0.0}, LineOffset -> {0.0, 0.0}, LineLength -> 0.5]].";
KeepPower::usage ="KeepPower[Expression, Variable, ExpansionDepth] expands the Expression in Variable around zero up to the order specified in ExpansionDepth.\nExpansionDepth=3 expands up to the 3rd power of Variable.\nExpansionDepth=-1 will keep all negative powers of Variable.\nExpansionDepth={1,2} only gives back terms including powers between Variable^1 and Variable^2 (inclusiv)."
SigmaGamma::usage ="SigmaGamma[exp,had5]/SigmaGamma[exp,lep] contains the numeric value of the 5 quark/leptonic  contribution to the photon self energy at MZ. The values are defined by \!\(\*SubsuperscriptBox[\"\[CapitalDelta]\[Alpha]\", \"had\", \"5\"]\)(\!\(\*SubscriptBox[\"m\", \"z\"]\))  and \!\(\*SubscriptBox[\"\[CapitalDelta]\[Alpha]\", \"lep\"]\)(\!\(\*SubscriptBox[\"m\", \"z\"]\)) via SetDeltaAlpha[(Options)].";
SetDeltaAlpha::usage = "SetDeltaAlpha[(Options)] is used to specify the numeric values of \!\(\*SubsuperscriptBox[\"\[CapitalDelta]\[Alpha]\", \"had\", \"5\"]\)(\!\(\*SubscriptBox[\"m\", \"z\"]\)) and \!\(\*SubscriptBox[\"\[CapitalDelta]\[Alpha]\", \"lep\"]\)(\!\(\*SubscriptBox[\"m\", \"z\"]\)) in order to define the numeric value for the fermionic contributions to the photon self energy at \!\(\*SubscriptBox[\"m\", \"z\"]\) (SigmaGamma[exp,had5], SigmaGamma[exp,lep]).\nPossible options and their default values are:\nDeltaAlphaHadronic5AtMZ->277.45*10^(-4),\nDeltaAlphaLeptonicAtMZ->(314.19+0.78)*10^(-4),\nMZ\[Rule]91.1876,\nSilent->False.";
ToDataResultName::usage="ToDataResultName[ListOfContributions, DataSet] creates list of names for all contributions in the ListOfContributions.\nTherefore the symbol name of DataSet and the symbol names appearing in the ListOfContributions are used.";
CreateDataSetResults::usage="CreateDataSetResults[ListOfContributions, DataSet(,Options)] calculates all contributions contained in the ListOfContributions using the DataSet.\nThe numeric results are stored in corresponding Mathematica variables created by ToDataResultName[ListOfContributions, DataSet].\nPossible options and their default values are:\nSilent -> False.";
ClearDataSetResultVariables::usage="ClearDataSetResultVariables[ListOfContributions, DataSet(,Options)] clears all Mathematica variables, whose symbol name is element of the list set up by ToDataResultName[ListOfContributions, DataSet].\nPossible options and their default values are:\nSilent -> False.";
SaveDataSetResults::usage="SaveDataSetResults[ListOfContributions, DataSet(,Options)] saves the content of all Mathematica variables, whose symbol name is element of the list set up by ToDataResultName[ListOfContributions, DataSet], to corresponding .res files in the folder specified via the path option.\nThe function hands down all options accepted by SaveDataResult[DataResultVariable(,Options)].";
LoadDataSetResults::usage="LoadDataSetResults[ListOfContributions, DataSet] loads all DataResults corresponding to ListOfContributions and DataSet from .res files into Mathematica variables with symbol names, which are element of the string list generated by ToDataResultName[ListOfContributions, DataSet].\nThe function hands down all options accepted by LoadDataResult[DataSetName(,Options))].";
DeleteDataSetResultFiles::usage="DeleteDataSetResultFiles[ListOfContributions, DataSet] deletes all .res file on hard drive corresponding to ListOfContributions and DataSet.\nThe function hands down all options accepted by DeleteDataResultFile[DataSetName(,Options)].";
SumUpDataResults::usage="SumUpDataResults[DataSetResult1, DataSetResult2, ...] can be used to add the y-values multiple DataSetResults.";
CalcInterpolation::usage="CalcInterpolation[ListOfContributions, DataSet][x] is used to interpolate the numerical value induced by the ListOfContributions using the given DataSet at position x.";
PluginRealSfermionMixingMatrix::usage="PluginRealSfermionMixingMatrix[expression_] replaces all mixing matrix elements by cos(theta) and sin(theta) with theta the mixing angle.";
DisplayListOfContributions::usage="DisplayListOfContributions[(Options)] displays all defined contributions.\nThe default option Output -> String returns the list as String.\nOutput -> List returns the output in a mathemtica list.";
DisplayContributionInformation::usage="DisplayContributionInformation[] prints out usage information.";
DisplayDataResults::usage="DisplayDataResults[(Options)] displays all files with extension .res in the folder definend in the Path option.\nDefault Path is the $TQPATDataResultFolder.";
LoadDataResult::usage="LoadDataResult[DataResultName(,Options)] loads the DataResult from file with name (string) DataResultName to the mathematica variable with same name. Default options are Path->$TQPATDataResultFolder, VariableName->Standard (->variable name is equal to DataResultName). VariableName can be any string usable for mathematica variables.";
SaveDataResult::usage="SaveDataResult[DataResultVariable(,Options)] saves the DataResultVariable to file with equal name (default options) in the folder defined via Path option. The name of the file can be specified by setting the option FileName to a string.";
DeleteDataResultFile::usage="DeleteDataResultFile[DataResultName(,Options)] removes the file with name DataResultName from the folder specified by the Path option.";
DisplayDataSets::usage="DisplayDataSets[(Options)] displays all files with extension .set in the folder definend in the Path option.\nDefault Path is the $TQPATDataSetFolder.";
LoadDataSet::usage="LoadDataSet[DataSetName(,Options)] loads the DataSet from file with name (string) DataSetName to the mathematica variable with same name. Default options are Path->$TQPATDataSetFolder, VariableName->Standard (->variable name is equal to DataSetName). VariableName can be any string usable for mathematica variables.";
SaveDataSet::usage="SaveDataSet[DataSetVariable(,Options)] saves the DataSetVariable to file with equal name (default options) in the folder defined via Path option. The name of the file can be specified by setting the option FileName to a string.";
DeleteDataSetFile::usage="DeleteDataSetFile[DataSetName(,Options)] removes the file with name DataSetName from the folder specified by the Path option.";
CreateDataSet::usage="CreateDataSet[(Options)] uses SPheno to create DataSets describing mSUGRA slopes. The default Options  {VariableParameter -> x, m0 -> 0.4 x, m12 -> x, A0 -> -0.4 x, tanbeta -> 10, signmu -> 1, ParameterMin -> 100, ParameterMax -> 350,NumberOfPoints -> 51, Alfa -> 0.00729735, CW2 -> 0.777876, MB2 -> 17.64, MC2 -> 1.69, MD2 -> 0.000025, ME2 -> 2.61121*10^-7, ML2 -> 3.1684, MM2 -> 0.011236, MS2 -> 0.01, MU2 -> 0.000025, MW2 -> 6468.18, MZ2 -> 8315.18, SW2 -> 0.222124, Alfas -> 0.12, MT2 -> 30625} creates a DataSet following the SPS1 slope.";
CreateSLHADataSet::usage="CreateDataSet[(Options)] uses SLAM as interface to spectrum generators or direct SLHA input.";
CreateSimpleDataSet::usage ="CreateSimpleDataSet[PreDataSet, SubstitutionRule(,Options)] creates a complete DataSet from one element of DataSet (PreDataSet) using the given SubstitutionRule (Rule or List of Rules). The the default Options are: {VariableParameter ->x, ParameterMin -> 100, ParameterMax -> 1000, NumberOfPoints -> 26}.";
ReplaceValuesInDataSet::usage = "ReplaceValuesInDataSet[DataSet, ListOfNewRules] replaces all rules in a DataSet according to list of replacement rules defined in ListOfNewRules.\n Example:\nDataSet={{1,{MT2->175,MH2->30}},{2,{MT2->160,MH2->30}}};\nListOfNewRules={MT2->x^2,MH2->y^2};\nx=ReplaceValuesInDataSet[DataSet,ListOfNewRules]\nleads to:\nx={{1,{MT2->x^2,MH2->y^2}},{2,{MT2->x^2,MH2->y^2}}}.";
DoAllNumerics::usage = "DoAllNumerics[ListOfContributions, DataSet(, Options)] evaluates the ListOfContributions using the DataSet. If the option AddUpAllContributions->True is set all contributions in the list are added up to one value. This is done by default.";
Set$TQPATSMDefaultValues::usage = "Set$TQPATSMDefaultValues[DataSet] updates the default SM values in $TQPATSMDefaultValues with DataSet. A list of replacement rules for e.g. DataSet[[1,2]] can be handled as argument, too";
Set$TQPATMSSMDefaultValues::usage = "Set$TQPATMSSMDefaultValues[DataSet] updates the default SM values in $TQPATMSSMDefaultValues with DataSet. A list of replacement rules for e.g. DataSet[[1,2]] can be handled as argument, too";
$TQPATSMDefaultValues::usage = "$TQPATSMDefaultValues contains a normal ordered list of numerical replacement rules for SM parameters.\nIt provides default numerical values in case where needed values are not defined.\n$TQPATSMDefaultValues can be updated with the function Set$TQPATMSSMDefaultValues[DataSet].";
$TQPATMSSMDefaultValues::usage = "$TQPATMSSMDefaultValues contains a normal ordered list of numerical replacement rules for MSSM parameters.\nIt provides default numerical values in case where needed values are not defined.\n$TQPATMSSMDefaultValues can be updated with the function Set$TQPATMSSMDefaultValues[DataSet].";
TQPATDefault::usage = "TQPATDefault[x] labels the numeric value x as default.";
CorrectionQ::usage = "CorrectionQ[x] gives True/False when x is /not one of the following symbols: HeliL, HeliR, DeltaC, Direct.";
ElementListOfContributionsQ::usage = "ElementListOfContributionsQ[x] gives True/False when x has a/no defined Contribution.\nThat means: ElementListOfContributionsQ[DeltaC[White, Blue]] -> False, ElementListOfContributionsQ[DeltaC[SMEW, Gammatt]] -> True";

LabelContourPlot::usage = "LabelContourPlot[ContourPlotHolded(, Options)] creates an interactive contour plot where new labels can be inserted and removed by hand.\nContourPlotHolded has to be a holded ContourPlot (Hold[ContourPlot[...]]).\nPossible options and their default values are:\nLabelPrecision -> 2. Sets the number of non zero gigits kept in a label.\nLabelFunction ->TQPATLabelFunction. Specifies the pure function which draws each label.";
TQPATLabelFunction::usage="Pure function that defines the layout of each label. Used as default option in LabelContourPlot[CountourPlotHolded(, Options)].";
$LabelList::usage="Contains a list of possition (x,y) and current value (z) of all labels created with LabelContourPlot[CountourPlotHolded(, Options)].\nNote that the list is created dynamically during the evaluation of LabelContourPlot.";

(*Symbols*)
BornHeliL::usage ="BornHeliL represents the left handed helicity amplitude at Born level.";
BornHeliR::usage ="BornHeliR represents the right handed helicity amplitude at Born level.";

FullSMHeliL::usage ="FullSMHeliL represents the left handed 1-loop helicity amplitude in the SM.";
FullSMHeliR::usage ="FullSMHeliR represents the right handed 1-loop helicity amplitude in the SM.";

FullMSSMDeltaC::usage ="FullMSSMDeltaC contains all contributions to the relative correction of the cross section \[CapitalDelta] at threshold in the MSSM using finite fermions masses in VB SE contributions.";
FullMSSMNoLFMsDeltaC::usage="FullMSSMNoLFMsDeltaC contains all contributions to the relative correction of the cross section \[CapitalDelta] at threshold in the MSSM using SigmaGamma[exp,had5] and SigmaGamma[exp,lep] in VB SE contributions to enable the limit for vanishing light quark masses. Thus only the top quark mass is kept in the THDM VB SE contributions.";
FullMSSMNoLFMsMBNot0DeltaC::usage="FullMSSMNoLFMsMBNot0DeltaC contains all contributions to the relative correction of the cross section \[CapitalDelta] at threshold in the MSSM using SigmaGamma[exp,had5] and SigmaGamma[exp,lep] in VB SE contributions to enable the limit for vanishing light quark masses. Here only the bottom and top quark mass are kept in the THDM VB SE contributions.";
FullTHDMDeltaC::usage ="FullTHDMDeltaC contains all contributions to the relative correction of the cross section \[CapitalDelta] at threshold in the THDM using finite fermions masses in VB SE contributions.";
FullTHDMNoLFMsDeltaC::usage="FullTHDMNoLFMsDeltaC contains all contributions to the relative correction of the cross section \[CapitalDelta] at threshold in the THDM using SigmaGamma[exp,had5] and SigmaGamma[exp,lep] in VB SE contributions to enable the limit for vanishing light quark masses. Thus only the top quark mass is kept in the VB SE contributions.";
FullTHDMNoLFMsMBNot0DeltaC::usage="FullTHDMNoLFMsMBNot0DeltaC contains all contributions to the relative correction of the cross section \[CapitalDelta] at threshold in the THDM using SigmaGamma[exp,had5] and SigmaGamma[exp,lep] in VB SE contributions to enable the limit for vanishing light quark masses. Here only the bottom and top quark mass are kept in the VB SE contributions.";
FullSMDeltaC::usage ="FullSMDeltaC contains all contributions to the relative correction of the cross section \[CapitalDelta] at threshold in the SM using finite fermions masses in VB SE contributions.";
FullSMNoLFMsDeltaC::usage ="FullSMNoLFMsDeltaC contains all contributions to the relative correction of the cross section \[CapitalDelta] at threshold in the SM using SigmaGamma[exp,had5] and SigmaGamma[exp,lep] in VB SE contributions to enable the limit for vanishing light quark masses. Thus only the top quark mass is kept in the VB SE contributions.";

tVertexSMDeltaC::usage ="tVertexSMDeltaC contains all ttbar vertex contributions to the relative correction of the cross section \[CapitalDelta] at threshold in the SM neglecting all light fermion masses (#=5).";
eVertexSMDeltaC::usage ="eVertexSMDeltaC contains all e+e- vertex contributions to the relative correction of the cross section \[CapitalDelta] at threshold in the SM neglecting all light fermion masses (#=5).";
SESMDeltaC::usage ="SESMDeltaC contains all vector boson selfenergie contributions to the relative correction of the cross section \[CapitalDelta] at threshold in the SM";
BoxSMDeltaC::usage ="BoxSMDeltaC contains all box contributions to the relative correction of the cross section \[CapitalDelta] at threshold in the SM neglecting all light fermion masses (#=5).";
tVertexTHDMDeltaC::usage ="tVertexTHDMDeltaC contains all ttbar vertex contributions to the relative correction of the cross section \[CapitalDelta] at threshold in the SM.";
eVertexTHDMDeltaC::usage ="eVertexTHDMDeltaC contains all box contributions to the relative correction of the cross section \[CapitalDelta] at threshold in the THDM neglecting all light fermion masses (#=5).";
SETHDMDeltaC::usage ="SETHDMDeltaC contains all vector boson selfenergie contributions to the relative correction of the cross section \[CapitalDelta] at threshold in the THDM using finite fermions masses.";
BoxTHDMDeltaC::usage ="BoxTHDMDeltaC contains all box contributions to the relative correction of the cross section \[CapitalDelta] at threshold in the THDM neglecting all light fermion masses (#=5).";
tVertexGluinoDeltaC::usage ="tVertexGluinoDeltaC contains the gluino (SUSYQCD) contribution to the relative correction of the cross section \[CapitalDelta] at threshold in the MSSM.";
tVertexChaDeltaC::usage ="tVertexChaDeltaC contains the ttbar vertex chargino contribution to the relative correction of the cross section \[CapitalDelta] at threshold in the MSSM.";
tVertexNeuDeltaC::usage ="tVertexNeuDeltaC contains the ttbar vertex neutralino contribution to the relative correction of the cross section \[CapitalDelta] at threshold in the MSSM.";
eVertexChaDeltaC::usage ="eVertexChaDeltaC contains the e+e- vertex chargino contribution to the relative correction of the cross section \[CapitalDelta] at threshold in the MSSM.";
eVertexNeuDeltaC::usage ="eVertexNeuDeltaC contains the e+e- vertex neutralino contribution to the relative correction of the cross section \[CapitalDelta] at threshold in the MSSM.";
SEChaNeuDeltaC::usage ="SEChaNeuDeltaC contains the vector boson selferngie contribution of neutralinos and charginos to the relative correction of the cross section \[CapitalDelta] at threshold in the MSSM.";
SESfermionDeltaC::usage ="SESfermionDeltaC contains the vector boson selferngie contribution of sfermion to the relative correction of the cross section \[CapitalDelta] at threshold in the MSSM.";
QCDDeltaC::usage ="QCDDeltaC contains the one loop QCD contribution to the relative correction of the cross section \[CapitalDelta] at threshold.";
SEMSSMDeltaC::usage ="SEMSSMDeltaC contains all vector boson selfergie contributions to the relative correction of the cross section \[CapitalDelta] at threshold in the MSSM.";

(*$Variables*)
$TQPATDir::usage = "$TQPATDir is a string which defines the path to this package on your system.";
$TQPATProgramDir::usage = "$TQPATProgramDir is a string which defines the path to the TQPAT folder on your system.";
$TQPATDataSetDir::usage = "$TQPATDataSetDir is a string which defines the path to the default dataset directory, which contains all predefined DataSet (.set) files.";
$TQPATDataResultDir::usage = "$TQPATDataResultDir is a string which defines the path to the default dataresult directory, which contains DataResult (.res) files.";
$TQPATFortranDir::usage = "$TQPATFortranDir is a string which defines the path to the fortranprograms directory.";
$TQPATExtrapolationDataDir::usage = "$TQPATExtrapolationDataDir is a string which defines the path to the extrapolation data.";

(* Options *)
SLHAFilePath::usage = "Either contains the path to the SLHA input file given as string, or is not a string.
In the first case SLAM is only used to load the input file.
In the second case SLAM is used to run a spectrum generator in order to create SLHA input.";
GridProps::usage = "Defines the grid layout to be used. The following format is required:
 {{x1min, x1max, x1stepsize}, ... , {xnmin, xnmax, xnsetpsize}} 
 This will generate a n-dimensional grid with corresponding minimal and maximal value filled with additional grid points using the given step size.
 A special for a 1-dimensional grid would be:
 {{150,200,10}}
 Leading to to grid: 150, 160, 170, 180, 190, 200.
 The ordering of sublists corresponds to the ordering of function arguments of the GridFunction option.";
GridFunction::usage = "Has to be a pure function which defines the dependence of the SLHA input on the grid variables.
The simple example:
{Model->\"lightstop\",MA->#1,tanbeta->#2}&
 leads to a two dimensional grid in dependence of MA and tanbeta in the light stop scenario.
 Note that there can be only n slots (#n), where n is the grid dimensions present in GridProps option.";


Begin["`Private`"];
$TQPATDir = SetDirectory[DirectoryName[System`Private`FindFile[$Input]]];

ResetDirectory[];

$TQPATProgramDir = ToFileName[{$TQPATDir, "TQPAT"}];
$TQPATDataSetDir = ToFileName[{$TQPATProgramDir, "datasets"}];
$TQPATDataResultDir = ToFileName[{$TQPATProgramDir, "dataresults"}];
$TQPATSPhenoLinkDir = ToFileName[{$TQPATProgramDir, "sphenolink"}];
$TQPATFortranDir = ToFileName[{$TQPATProgramDir, "fortranprograms"}];
$TQPATExtrapolationDataDir= ToFileName[{$TQPATProgramDir, "extrapolationdata"}];



Block[{$Path={$TQPATProgramDir,$TQPATDir}},
(*Loading user specific configurations*)
<<"TQPAT.config"



(*Loading Function Definitions*)
<<"functions.m"
]

End[];





(*Autogenerate usage definition for all contributions *)
(Evaluate[#]::usage = "ContributionType.\nUse DisplayContributionInformation[ContributionType->" <> ToString[#] <> ", ContributionContent->_] for more information.";) & /@ (#[[1]] & /@ DisplayListOfContributions[Output -> List]);
(Evaluate[#]::usage = "ContributionContent.\nUse DisplayContributionInformation[ContributionType->_,ContributionContent->" <> ToString[#] <> "] for more information.";) & /@ Union[Flatten[#[[2]] & /@ DisplayListOfContributions[Output -> List]]];


Begin["`Private`"];
Block[{$Path={$TQPATProgramDir,$TQPATDir}},
(*Loading Contribution Definitions*)
<<"contributions.m";
]

End[];
EndPackage[];


(*Creating $TQPATSMDefaultValues and $TQPATMSSMDefaultValues *)
LoadDataSet["SPSPointsDataSet",SLAM`Silent->True];
Set$TQPATSMDefaultValues[SPSPointsDataSet[[1,2]]];
Set$TQPATMSSMDefaultValues[SPSPointsDataSet[[1,2]]];
Clear[SPSPointsDataSet];

(*Setting DeltaAlphaHadronic5 and DeltaAlphaLeptonic*)
SetDeltaAlpha[Silent->True];

(*Loading MathLink executables*)
ListOfAllFortranProgs = StringDrop[ToString[#], 2] & /@ Select[DisplayListOfContributions[Output -> List], MatchQ[#, {Extrapolation, {a___}}] &][[1, 2]];
cntr = 1;
If[Head[Install[#]] =!= LinkObject, Print["Couldn't connect to the MathLink executable " <> ListOfAllFortranProgs[[cntr]] <> "."]; cntr++, Print["Connection to the MathLink executable " <> ListOfAllFortranProgs[[cntr]] <> " successful!"]; cntr++] & /@ (($TQPATFortranDir <> #) & /@ ListOfAllFortranProgs)
Clear[ListOfAllFortranProgs, cntr];


(*Exporting SLAM variables to Global if SLAM is not used *)
If[!((Head[$SLAMPath] === String) && (FileType[$SLAMPath] === File)),

Begin["SLAM`"];
tanbeta::usage="tan(\[Beta]). Ratio of the two Higgs vacuum expectation values.
tan(\[Beta])=\!\(\*SubscriptBox[\(v\), \(u\)]\)/\!\(\*SubscriptBox[\(v\), \(d\)]\).";
m0::usage="\!\(\*SubscriptBox[\(m\), \(0\)]\). Unified soft breaking parameters of scalars at the GUT scale.";
m12::usage="\!\(\*SubscriptBox[\(m\), \(1/2\)]\). Unified soft breaking parameters of gauginos at the GUT scale.";
A0::usage="\!\(\*SubscriptBox[\(A\), \(0\)]\).Trilinear coupling soft susy breaking parameter at the GUT scale. Used for e.g. in the msugra scenario";
Silent::usage="Can be True or False.
If True ObtainLesHouchesSpectrum will not print processing messages.";
signmu::usage="Sign[\!\(\*SubscriptBox[\(\[Mu]\), \(SUSY\)]\)]. Sign of the soft breaking term ~\!\(\*SubscriptBox[\(H\), \(u\)]\)\!\(\*SubscriptBox[\(H\), \(d\)]\).
Input parameter in SUSY breaking scenarios.";
End[];,

Begin["SLAM`"];
A0::usage="\!\(\*SubscriptBox[\(A\), \(0\)]\).Trilinear coupling soft susy breaking parameter at the GUT scale. Used for e.g. in the msugra scenario";
End[];

];

