(*Loading analytic results*)

Begin["TQPAT`Private`"];

Get[ToFileName[{$TQPATProgramDir,"analyticresults"},"BOX_SM.m"]];
Get[ToFileName[{$TQPATProgramDir,"analyticresults"},"eeV_MSSM.m"]];
Get[ToFileName[{$TQPATProgramDir,"analyticresults"},"gammatt_Chargino.m"]];
Get[ToFileName[{$TQPATProgramDir,"analyticresults"},"gammatt_CharginoMB0.m"]];
Get[ToFileName[{$TQPATProgramDir,"analyticresults"},"gammatt_CharginoCKM.m"]];
Get[ToFileName[{$TQPATProgramDir,"analyticresults"},"gammatt_Gluino.m"]];
Get[ToFileName[{$TQPATProgramDir,"analyticresults"},"gammatt_Neutralino.m"]];
Get[ToFileName[{$TQPATProgramDir,"analyticresults"},"VSEV_MSSM.m"]];
Get[ToFileName[{$TQPATProgramDir,"analyticresults"},"VSEV_SM.m"]];
Get[ToFileName[{$TQPATProgramDir,"analyticresults"},"Vtt_SM.m"]];
Get[ToFileName[{$TQPATProgramDir,"analyticresults"},"Vtt_THDM.m"]];
Get[ToFileName[{$TQPATProgramDir,"analyticresults"},"Ztt_Chargino.m"]];
Get[ToFileName[{$TQPATProgramDir,"analyticresults"},"Ztt_CharginoMB0.m"]];
Get[ToFileName[{$TQPATProgramDir,"analyticresults"},"Ztt_CharginoOld.m"]];
Get[ToFileName[{$TQPATProgramDir,"analyticresults"},"Ztt_Gluino.m"]];
Get[ToFileName[{$TQPATProgramDir,"analyticresults"},"Ztt_Neutralino.m"]];

(*Constants which transform differnet corrections into helicity amplitudes*)
SigmaGammaToHeliFactor[L]=-(Alfa*Pi)/(6*MT2^2);
SigmaGammaToHeliFactor[R]=-(Alfa*Pi)/(6*MT2^2);

SigmaZToHeliFactor[L]=-(Alfa*Pi*(-1+2*SW2)*(-3+8*SW2))/(6*CW2*(-4*MT2+MZ2)^2*SW2);
SigmaZToHeliFactor[R]=-(Alfa*Pi*(-3+8*SW2))/(3*CW2*(-4*MT2+MZ2)^2);

SigmaGammaZToHeliFactor[L]=(Alfa*Pi*(7-16*SW2))/(12*Sqrt[CW2]*MT2*(4*MT2-MZ2)*Sqrt[SW2]);
SigmaGammaZToHeliFactor[R]=(Alfa*Pi*(3-16*SW2))/(12*Sqrt[CW2]*MT2*(4*MT2-MZ2)*Sqrt[SW2]);

LambdaGammatttoHeliFactor[L]=-EL/(4*MT2);
LambdaGammatttoHeliFactor[R]=-EL/(4*MT2);

LambdaZtttoHeliFactor[L]=-EL*(SW2-1/2)/(Sqrt[CW2]*Sqrt[SW2])/(4*MT2-MZ2);
LambdaZtttoHeliFactor[R]=-EL/(Sqrt[CW2])*Sqrt[SW2]*1/(4*MT2-MZ2);

LambdaeeGammatoHeliFactor[V]=2/3*EL/(4*MT2);

LambdaeeZtoHeliFactor[V]=-EL/(Sqrt[CW2]*Sqrt[SW2])*(1/4-2/3*SW2)/(4*MT2-MZ2);
LambdaeeZtoHeliFactor[A]=EL/(4*Sqrt[CW2]*Sqrt[SW2])/(4*MT2-MZ2);


(*Born*)
hBorn[A] = (Alfa*Pi*(-3 + 8*SW2))/(12*(4*MT2 - MZ2)*(-1 + SW2)*SW2);
hBorn[V] = (Alfa*Pi*(8*MZ2*(-1 + SW2)*SW2 + 3*MT2*(1 + 4*SW2)))/(12*MT2*(4*MT2 - MZ2)*(-1 + SW2)*SW2);
hBorn[R] = hBorn[A] + hBorn[V];
hBorn[L] = hBorn[V] - hBorn[A];
hBornSquared = Simplify[hBorn[L]^2 + hBorn[R]^2];

(*Special for simple numerics*)
(*{Born, TreeL, "contains the left handed contribution from the two born diagrams."}*) 
Contribution[Born, TreeL] = hBorn[L];
(*{Born, TreeR, "contains the right handed contribution from the two born diagrams."}*) 
Contribution[Born, TreeR] = hBorn[R];

ToHelicityAmplitude[TreeL, L] = 1;
ToHelicityAmplitude[TreeL, R] = 0;
ToHelicityAmplitude[TreeR, R] = 1;
ToHelicityAmplitude[TreeR, L] = 0;
ToCrossectionCorrection[TreeL] = 2/hBornSquared*hBorn[L];
ToCrossectionCorrection[TreeR] = 2/hBornSquared*hBorn[R];


(*Numeric Extrapolation with FORTRAN CrossSectionCorrection ONLY!*)
(*{DCAllSMBoxes, Extrapolation, "uses the external FORTRAN program AllSMBoxes to calculate the relative correction of the cross section induced by all SM box diagrams above the threshold in order to extrapolate it onto threshold."}*)
(*Contribution[DCAllSMBoxes, Extrapolation] <- For Contribution Listing*)
Contribution[DCAllSMBoxes,a___, Extrapolation] := List[DCAllSMBoxes,a];
(*{DCCharginoBox, Extrapolation, "uses the external FORTRAN program CharginoBox to calculate the relative correction of the cross section induced by the single chargino box diagram above the threshold in order to extrapolate it onto threshold."}*)
(*Contribution[DCCharginoBox, Extrapolation] <- For Contribution Listing*)
Contribution[DCCharginoBox,a___, Extrapolation] := List[DCCharginoBox,a];
(*{DCNeutralinoBoxes, Extrapolation, "uses the external FORTRAN program NeutralinoBoxes to calculate the relative correction of the cross section induced by the two neutralino box diagrams above the threshold in order to extrapolate it onto threshold."}*)
(*Contribution[DCNeutralinoBoxes, Extrapolation] <- For Contribution Listing*)
Contribution[DCNeutralinoBoxes,a___, Extrapolation] := List[DCNeutralinoBoxes,a];
ToCrossectionCorrection[Extrapolation] = 1;

(*SEs*)
(*{SMEWNoLFMs, GammaGamma,"contains the photon-photon selfenergie contribution obtained in the SM neglecting all light fermion masses via the usage of experimental data for DeltaAlpha (SigmaGamma[exp,had5] and SigmaGamma[exp,lep]) at MZ."}*) 
Contribution[SMEWNoLFMs, GammaGamma] = SigmaGammaRSmallLogsMassless[4*MT2];
(*{SMEWNoLFMs, ZZ,"contains the elektroweak Z-Z selfenergie contribution obtained in the SM neglecting all light fermion masses via the usage of experimental data for DeltaAlpha (SigmaGamma[exp,had5] and SigmaGamma[exp,lep]) at MZ."}*)
Contribution[SMEWNoLFMs, ZZ] = SigmaZRSmallLogsMassless[4*MT2]/. MH2 -> Mh02;
(*{SMEWNoLFMs, GammaZ,"contains the elektroweak photon-Z transition contribution obtained in the SM neglecting all light fermion masses."}*)
Contribution[SMEWNoLFMs, GammaZ] = SigmaGammaZRMassless[4*MT2] /. MH2 -> Mh02;
(*{SMEW, GammaGamma,"contains the photon-photon selfenergie contribution obtained in the SM while keeping all masses."}*) 
Contribution[SMEW, GammaGamma] = SigmaGammaR[4*MT2];
(*{SMEW, GammaZ,"contains the elektroweak photon-Z transition contribution obtained in the SM while keeping all masses."}*)
Contribution[SMEW, GammaZ] = SigmaGammaZR[4*MT2] /. MH2 -> Mh02;
(*{SMEW, ZZ,"contains the elektroweak Z-Z selfenergie contribution obtained in the SM while keeping all masses."}*)
Contribution[SMEW, ZZ] = SigmaZR[4*MT2] /. MH2 -> Mh02;
(*{THDMEWNoLFMs, GammaGamma,"contains the elektroweak photon-photon selfenergie contribution obtained in the THDM neglecting all light fermion masses via the usage of experimental data for DeltaAlpha (SigmaGamma[exp,had5] and SigmaGamma[exp,lep]) at MZ."}*)
Contribution[THDMEWNoLFMs, GammaGamma] = SigmaGammaRTHDMSmallLogsMassless[4*MT2]/. {SBA -> SB*CA - SA*CB, CBA -> SB*SA + CA*CB};
(*{THDMEWNoLFMs, GammaZ,"contains the elektroweak photon-Z transition contribution obtained in the THDM while neglecting all light fermion masses."}*)
Contribution[THDMEWNoLFMs, GammaZ] =  SigmaGammaZRTHDMMassless[4*MT2]/. {SBA -> SB*CA - SA*CB, CBA -> SB*SA + CA*CB};
(*{THDMEWNoLFMs, ZZ,"contains the elektroweak Z-Z selfenergie contribution obtained in the THDM while neglecting all light fermion masses via the usage of experimental data for DeltaAlpha (SigmaGamma[exp,had5] and SigmaGamma[exp,lep]) at MZ."}*)
Contribution[THDMEWNoLFMs, ZZ] =  SigmaZRTHDMSmallLogsMassless[4*MT2]/. {SBA -> SB*CA - SA*CB, CBA -> SB*SA + CA*CB};
(*{THDMEWNoLFMsMBNot0, GammaGamma,"contains the elektroweak photon-photon selfenergie contribution obtained in the THDM while neglecting all light fermion masses except the bottom and top quark mass via the usage of experimental data for DeltaAlpha (SigmaGamma[exp,had5] and SigmaGamma[exp,lep]) at MZ."}*)
Contribution[THDMEWNoLFMsMBNot0, GammaGamma] = SigmaGammaRTHDMSmallLogsMasslessMBNotZero[4*MT2]/. {SBA -> SB*CA - SA*CB, CBA -> SB*SA + CA*CB};
(*{THDMEWNoLFMsMBNot0, GammaZ,"contains the elektroweak photon-Z transition contribution obtained in the THDM while neglecting all light fermion masses except the bottom and top quark mass via the usage of experimental data for DeltaAlpha (SigmaGamma[exp,had5] and SigmaGamma[exp,lep]) at MZ."}*)
Contribution[THDMEWNoLFMsMBNot0, GammaZ] =  SigmaGammaZRTHDMMasslessMBNotZero[4*MT2]/. {SBA -> SB*CA - SA*CB, CBA -> SB*SA + CA*CB};
(*{THDMEWNoLFMsMBNot0, ZZ,"contains the elektroweak Z-Z selfenergie contribution obtained in the THDM while neglecting all light fermion masses except the bottom and top quark mass via the usage of experimental data for DeltaAlpha (SigmaGamma[exp,had5] and SigmaGamma[exp,lep]) at MZ."}*)
Contribution[THDMEWNoLFMsMBNot0, ZZ] =  SigmaZRTHDMSmallLogsMasslessMBNotZero[4*MT2]/. {SBA -> SB*CA - SA*CB, CBA -> SB*SA + CA*CB};
(*{THDMEW, GammaGamma,"contains the elektroweak photon-photon selfenergie contribution obtained in the THDM while keeping all masses."}*)
Contribution[THDMEW, GammaGamma] = SigmaGammaRTHDM[4*MT2] /. {SBA -> SB*CA - SA*CB, CBA -> SB*SA + CA*CB};
(*{THDMEW, GammaZ,"contains the elektroweak photon-Z transition contribution obtained in the THDM while keeping all masses."}*)
Contribution[THDMEW, GammaZ] = SigmaGammaZRTHDM[4*MT2] /. {SBA -> SB*CA - SA*CB, CBA -> SB*SA + CA*CB};
(*{THDMEW, ZZ,"contains the elektroweak Z-Z selfenergie contribution obtained in the THDM while keeping all masses."}*)
Contribution[THDMEW, ZZ] = SigmaZRTHDM[4*MT2] /. {SBA -> SB*CA - SA*CB, CBA -> SB*SA + CA*CB};
(*{CharginoNeutralino, GammaGamma,"contains the neutralino and chargino contribution to the photon-photon selfenergie obtained in the MSSM."}*)
Contribution[CharginoNeutralino, GammaGamma] = SigmaGammaRSUSYCha[4*MT2] /. {SBA -> SB*CA - SA*CB, CBA -> SB*SA + CA*CB};
(*{CharginoNeutralino, GammaZ,"contains the neutralino and chargino contribution to the photon-Z transition obtained in the MSSM."}*)
Contribution[CharginoNeutralino, GammaZ] = SigmaGammaZRSUSYChaNeu[4*MT2] /. {SBA -> SB*CA - SA*CB, CBA -> SB*SA + CA*CB};
(*{CharginoNeutralino, ZZ,"contains the neutralino and chargino contribution to the Z-Z selfenergie obtained in the MSSM."}*)
Contribution[CharginoNeutralino, ZZ] = SigmaZRSUSYChaNeu[4*MT2] /. {SBA -> SB*CA - SA*CB, CBA -> SB*SA + CA*CB};
(*{Sfermion, GammaGamma,"contains the sfermionic contribution to the photon-photon selfenergie obtained in the MSSM."}*)
Contribution[Sfermion, GammaGamma] = SigmaGammaRSUSYSfermion[4*MT2] /. {SBA -> SB*CA - SA*CB, CBA -> SB*SA + CA*CB};
(*{Sfermion, GammaZ,"contains the sfermionic contribution to the photon-Z transition obtained in the MSSM."}*)
Contribution[Sfermion, GammaZ] = SigmaGammaZRSUSYSfermion[4*MT2] /. {SBA -> SB*CA - SA*CB, CBA -> SB*SA + CA*CB};
(*{Sfermion, ZZ,"contains the sfermionic contribution to the Z-Z selfenergie obtained in the MSSM."}*)
Contribution[Sfermion, ZZ] = SigmaZRSUSYSfermion[4*MT2] /. {SBA -> SB*CA - SA*CB, CBA -> SB*SA + CA*CB};

(*Prefac to h[L,R]*)

ToHelicityAmplitude[GammaGamma, L] = SigmaGammaToHeliFactor[L];
ToHelicityAmplitude[GammaGamma, R] = SigmaGammaToHeliFactor[R];
ToHelicityAmplitude[GammaZ, L] = SigmaGammaZToHeliFactor[L];
ToHelicityAmplitude[GammaZ, R] = SigmaGammaZToHeliFactor[R];
ToHelicityAmplitude[ZZ, L] = SigmaZToHeliFactor[L];
ToHelicityAmplitude[ZZ, R] = SigmaZToHeliFactor[R];
ToCrossectionCorrection[GammaGamma] = Simplify[ 2*(hBorn[L]*SigmaGammaToHeliFactor[L] + hBorn[R]*SigmaGammaToHeliFactor[R])/hBornSquared];
ToCrossectionCorrection[GammaZ] = Simplify[2*(hBorn[L]*SigmaGammaZToHeliFactor[L] + hBorn[R]*SigmaGammaZToHeliFactor[R])/hBornSquared];
ToCrossectionCorrection[ZZ] = Simplify[2*(hBorn[L]*SigmaZToHeliFactor[L] + hBorn[R]*SigmaZToHeliFactor[R])/hBornSquared];

(*ttVertex*)
(*{Chargino, Gammatt,"contains the chargino/sbottom contribution at the photon-t-tbar vertex obtained in the MSSM.\nCKM = 1 is used.\nThe bottom mass is not neglected (needed for large tan(beta))."}*)
Contribution[Chargino, Gammatt] = aCharginoGamma;
(*{Chargino, Ztt,"contains the chargino/sbottom contribution at the Z-t-tbar vertex obtained in the MSSM.\nCKM = 1 is used.\nThe bottom mass is not neglected (needed for large tan(beta))."}*)
Contribution[Chargino, Ztt] = aCharginoZ;
(*{CharginoMB0, Gammatt,"contains the chargino/sbottom contribution at the photon-t-tbar vertex obtained in the MSSM.\nCKM = 1 is used.\nThe bottom mass is neglected (only possible for small tan(beta))."}*)
Contribution[CharginoMB0, Gammatt] = aCharginoGammaMB0;
(*{CharginoMB0, Ztt,"contains the chargino/sbottom contribution at the Z-t-tbar vertex obtained in the MSSM.\nCKM = 1 is used.\nThe bottom mass is neglected (only possible for small tan(beta))."}*)
Contribution[CharginoMB0, Ztt] = aCharginoZMB0;
(*{CharginoCKM, Gammatt,"contains the chargino/sbottom contribution at the photon-t-tbar vertex obtained in the MSSM.\nCKM matrix is kept.\nThe bottom mass is neglected (only possible for small tan(beta)).\nTo be used for testing, only."}*)
Contribution[CharginoCKM, Gammatt] = aCharginoGammaCKM;
(*{CharginoOld, Ztt,"contains the chargino/sbottom contribution at the photon-t-tbar vertex obtained in the MSSM.\nCKM = 1.\nThe bottom mass is neglected (only possible for small tan(beta)).\nOld result, agrees with CharginoMB0 Ztt."}*)
Contribution[CharginoOld, Ztt] = aCharginoZOld;
(*{Gluino, Gammatt,"contains the gluino/stop (SUSYQCD) contribution at the photon-t-tbar vertex obtained in the MSSM."}*)
Contribution[Gluino, Gammatt] = aGluinoGamma;
(*{Gluino, Ztt,"contains the gluino/stop (SUSYQCD) contribution at the Z-t-tbar vertex obtained in the MSSM."}*)
Contribution[Gluino, Ztt] = aGluinoZ;
(*{Neutralino, Gammatt,"contains the neutralino/stop contribution at the photon-t-tbar vertex obtained in the MSSM."}*)
Contribution[Neutralino, Gammatt] = aNeutralinoGamma;
(*{Neutralino, Ztt,"contains the neutralino/stop contribution at the Z-t-tbar vertex obtained in the MSSM."}*)
Contribution[Neutralino, Ztt] = aNeutralinoZ;
(*{THDMEW, Gammatt,"contains the electroweak contribution (except the pure QED ones) at the photon-t-tbar vertex obtained in the THDM.\nThe bottom quark mass is neglected (only possible for small tan(beta))."}*)
Contribution[THDMEW, Gammatt] = (aTHDMEWGamma[Alfa, SW2, MT2, Mh02, MHH2, MA02, MHp2, MZ2, MW2] /. {SBA -> SB*CA - SA*CB, CBA -> SB*SA + CA*CB});
(*{THDMEW, Ztt,"contains the electroweak contribution (except the pure QED ones) at the Z-t-tbar vertex obtained in the THDM.\nThe bottom quark mass is neglected (only possible for small tan(beta))."}*)
Contribution[THDMEW, Ztt] = (aTHDMEWZ[Alfa, SW2, MT2, Mh02, MHH2, MA02, MHp2, MZ2, MW2] /. {SBA -> SB*CA - SA*CB, CBA -> SB*SA + CA*CB});
(*{SMEW, Gammatt,"contains the electroweak contribution (except the pure QED ones) at the photon-t-tbar vertex obtained in the SM.\nThe bottom quark mass is neglected."}*)
Contribution[SMEW, Gammatt] = (aSMEWGamma[Alfa, SW2, MT2, MH2, MZ2, MW2] /. MH2 -> Mh02);
(*{SMEW, Ztt,"contains the electroweak contribution (except the pure QED ones) at the Z-t-tbar vertex obtained in the SM.\nThe bottom quark mass is neglected."}*)
Contribution[SMEW, Ztt] = (aSMEWZ[Alfa, SW2, MT2, MH2, MZ2, MW2] /. MH2 -> Mh02);
(*{QCD, Gammatt,"contains the QCD contribution at the photon/Z-t-tbar vertex obtained in the SM/THDM."}*)
Contribution[QCD, Gammatt] = aGGamma[Alfas];
(*{QCD, Ztt,"contains the QCD contribution at the photon/Z-t-tbar vertex obtained in the SM/THDM."}*)
Contribution[QCD, Ztt] = aGGamma[Alfas];

(*Prefac to h[L,R] (h[L,R] is defined by the total Left- or Right-handed amplitude including full propagator denominator!)*)

ToHelicityAmplitude[Gammatt, L] = (-2*Alfa*Pi)/(3*MT2);
ToHelicityAmplitude[Gammatt, R] = (-2*Alfa*Pi)/(3*MT2);
ToHelicityAmplitude[Ztt, L] = -(Alfa*Pi*(-1/2 + SW2)*(-3 + 8*SW2))/(3*CW2*(4*MT2 - MZ2)*SW2);
ToHelicityAmplitude[Ztt, R] = -(Alfa*Pi*(-3 + 8*SW2))/(3*CW2*(4*MT2 - MZ2));
ToCrossectionCorrection[Gammatt] = Simplify[2*(hBorn[L]*ToHelicityAmplitude[Gammatt, L] + hBorn[R]*ToHelicityAmplitude[Gammatt, R])/hBornSquared];
ToCrossectionCorrection[Ztt] = Simplify[2*(hBorn[L]*ToHelicityAmplitude[Ztt, L] + hBorn[R]*ToHelicityAmplitude[Ztt, R])/hBornSquared];


(*Box*)
(*{SMEW, BOXL,"contains the left handed box contribution obtained in the SM/THDM including the pure photon boxes.\nThe bottom and electron mass is neglected."}*)
Contribution[SMEW, BOXL] = hBox[L] /. Alfa2 -> Alfa^2;
(*{SMEW, BOXR,"contains the right handed box contribution obtained in the SM/THDM including the pure photon boxes.\nThe bottom and electron mass is neglected."}*)
Contribution[SMEW, BOXR] = hBox[R] /. Alfa2 -> Alfa^2;
(*{THDMEW, BOXL,"contains the left handed box contribution obtained in the SM/THDM including the pure photon boxes.\nThe bottom and electron mass is neglected."}*)
Contribution[THDMEW, BOXL] = hBox[L] /. Alfa2 -> Alfa^2;
(*{THDMEW, BOXR,"contains the right handed box contribution obtained in the SM/THDM including the pure photon boxes.\nThe bottom and electron mass is neglected."}*)
Contribution[THDMEW, BOXR] = hBox[R] /. Alfa2 -> Alfa^2;
(*{SMEWNoGamma, BOXL,"contains the left handed box contribution obtained in the SM/THDM without the pure photon boxes.\nThe bottom and electron mass is neglected."}*)
Contribution[SMEWNoGamma, BOXL] = hBoxNoGamma[L] /. Alfa2 -> Alfa^2;
(*{SMEWNoGamma, BOXR,"contains the right handed box contribution obtained in the SM/THDM without the pure photon boxes.\nThe bottom and electron mass is neglected."}*)
Contribution[SMEWNoGamma, BOXR] = hBoxNoGamma[R] /. Alfa2 -> Alfa^2;
ToHelicityAmplitude[BOXL, L] = 1;
ToHelicityAmplitude[BOXL, R] = 0;
ToHelicityAmplitude[BOXR, R] = 1;
ToHelicityAmplitude[BOXR, L] = 0;
ToCrossectionCorrection[BOXL] = 2/hBornSquared*hBorn[L];
ToCrossectionCorrection[BOXR] = 2/hBornSquared*hBorn[R];

(*eeVertex*)
(*{SMEW, eeGammaL,"contains the left handed electroweak (except pure QED) contribution at the e+e-photon vertex obtained in the SM/THDM.\nThe electron mass is neglected."}*)
Contribution[SMEW, eeGammaL] = LambdaeeGamma[L];
(*{SMEW, eeGammaR,"contains the right handed electroweak (except pure QED) contribution at the e+e-photon vertex obtained in the SM/THDM.\nThe electron mass is neglected."}*)
Contribution[SMEW, eeGammaR] = LambdaeeGamma[R];
(*{THDMEW, eeGammaL,"contains the left handed electroweak (except pure QED) contribution at the e+e-photon vertex obtained in the SM/THDM.\nThe electron mass is neglected."}*)
Contribution[THDMEW, eeGammaL] = LambdaeeGamma[L];
(*{THDMEW, eeGammaR,"contains the right handed electroweak (except pure QED) contribution at the e+e-photon vertex obtained in the SM/THDM.\nThe electron mass is neglected."}*)
Contribution[THDMEW, eeGammaR] = LambdaeeGamma[R];
(*{Neutralino, eeGammaL,"contains the left handed neutralino/selectron contribution at the e+e-photon vertex obtained in the MSSM.\nThe electron mass is neglected."}*)
Contribution[Neutralino, eeGammaL] = LambdaNeueeGamma[L];
(*{Neutralino, eeGammaR,"contains the right handed neutralino/selectron contribution at the e+e-photon vertex obtained in the MSSM.\nThe electron mass is neglected."}*)
Contribution[Neutralino, eeGammaR] = LambdaNeueeGamma[R];
(*{Chargino, eeGammaL,"contains the left handed chargino/sneutrino contribution at the e+e-photon vertex obtained in the MSSM.\nThe electron mass is neglected."}*)
Contribution[Chargino, eeGammaL] = LambdaChaeeGamma[L];


(*{SMEW, eeZL,"contains the left handed electroweak (except pure QED) contribution at the e+e-Z vertex obtained in the SM/THDM.\nThe electron mass is neglected."}*)
Contribution[SMEW, eeZL] = LambdaeeZ[L];
(*{SMEW, eeZR,"contains the right handed electroweak (except pure QED) contribution at the e+e-Z vertex obtained in the SM/THDM.\nThe electron mass is neglected."}*)
Contribution[SMEW, eeZR] = LambdaeeZ[R];
(*{THDMEW, eeZL,"contains the left handed electroweak (except pure QED) contribution at the e+e-Z vertex obtained in the SM/THDM.\nThe electron mass is neglected."}*)
Contribution[THDMEW, eeZL] = LambdaeeZ[L];
(*{THDMEW, eeZR,"contains the right handed electroweak (except pure QED) contribution at the e+e-Z vertex obtained in the SM/THDM.\nThe electron mass is neglected."}*)
Contribution[THDMEW, eeZR] = LambdaeeZ[R];
(*{Neutralino, eeZL,"contains the left handed neutralino/selectron contribution at the e+e-Z vertex obtained in the MSSM.\nThe electron mass is neglected."}*)
Contribution[Neutralino, eeZL] = LambdaNeueeZ[L];
(*{Neutralino, eeZR,"contains the right handed neutralino/selectron contribution at the e+e-Z vertex obtained in the MSSM.\nThe electron mass is neglected."}*)
Contribution[Neutralino, eeZR] = LambdaNeueeZ[R];
(*{Chargino, eeZL,"contains the left handed chargino/sneutrino contribution at the e+e-Z vertex obtained in the MSSM.\nThe electron mass is neglected."}*)
Contribution[Chargino, eeZL] = LambdaChaeeZ[L];

ToHelicityAmplitude[eeGammaL, L] = (-2*Alfa*Pi)/(3*MT2);
ToHelicityAmplitude[eeGammaL, R] = 0;
ToHelicityAmplitude[eeGammaR, R] = (-2*Alfa*Pi)/(3*MT2);
ToHelicityAmplitude[eeGammaR, L] = 0;

ToHelicityAmplitude[eeZL, L] = (-2*Alfa*Pi*(1 - 2*SW2)*(1/4 - (2*SW2)/3))/(CW2*(4*MT2 - MZ2)*SW2);
ToHelicityAmplitude[eeZL, R] = 0;
ToHelicityAmplitude[eeZR, R] = (4*Alfa*Pi*(1/4 - (2*SW2)/3))/(CW2*(4*MT2 - MZ2));
ToHelicityAmplitude[eeZR, L] = 0;

ToCrossectionCorrection[eeGammaL] = Simplify[2*(hBorn[L]*ToHelicityAmplitude[eeGammaL, L])/hBornSquared];
ToCrossectionCorrection[eeGammaR] = Simplify[2*(hBorn[R]*ToHelicityAmplitude[eeGammaR, R])/hBornSquared];
ToCrossectionCorrection[eeZL] = Simplify[2*(hBorn[L]*ToHelicityAmplitude[eeZL, L])/hBornSquared];
ToCrossectionCorrection[eeZR] = Simplify[2*(hBorn[R]*ToHelicityAmplitude[eeZR, R])/hBornSquared];




(*Shorthands for different correction contributions*) 

(*helicity amplitudes*)
BornHeliL = {HeliL[Born, TreeL]};
BornHeliR = {HeliR[Born, TreeR]};


tVertexSMHeliL = {HeliL[SMEW, Gammatt], HeliL[SMEW, Ztt]};
eVertexSMHeliL = {HeliL[SMEW, eeGammaL], HeliL[SMEW, eeZL]};
SESMHeliL = {HeliL[SMEW, ZZ], HeliL[SMEW, GammaZ], HeliL[SMEW, GammaGamma]};
BoxSMHeliL = {HeliL[SMEW, BOXL]};

tVertexSMHeliR = {HeliR[SMEW, Gammatt], HeliR[SMEW, Ztt]};
eVertexSMHeliR = {HeliR[SMEW, eeGammaR], HeliR[SMEW, eeZR]};
SESMHeliR = {HeliR[SMEW, ZZ], HeliR[SMEW, GammaZ], HeliR[SMEW, GammaGamma]};
BoxSMHeliR = {HeliR[SMEW, BOXR]};

tVertexTHDMHeliL = {HeliL[THDMEW, Gammatt], HeliL[THDMEW, Ztt]};
eVertexTHDMHeliL = eVertexSMHeliL;
SETHDMHeliL = {HeliL[THDMEW, ZZ], HeliL[THDMEW, GammaZ], HeliL[THDMEW, GammaGamma]};
BoxTHDMHeliL = BoxSMHeliL;

tVertexTHDMHeliR = {HeliR[THDMEW, Gammatt], HeliR[THDMEW, Ztt]};
eVertexTHDMHeliR = eVertexSMHeliR;
SETHDMHeliR = {HeliR[THDMEW, ZZ], HeliR[THDMEW, GammaZ], HeliR[THDMEW, GammaGamma]};
BoxTHDMHeliR = BoxSMHeliR;

FullSMHeliL = {HeliL[SMEW, Gammatt], HeliL[SMEW, Ztt], HeliL[SMEW, ZZ], HeliL[SMEW, GammaZ], HeliL[SMEW, GammaGamma], HeliL[SMEW, eeGammaL], HeliL[SMEW, eeZL], HeliL[SMEW, BOXL]};
FullSMHeliR = {HeliR[SMEW, Gammatt], HeliR[SMEW, Ztt], HeliR[SMEW, ZZ], HeliR[SMEW, GammaZ], HeliR[SMEW, GammaGamma], HeliR[SMEW, eeGammaR], HeliR[SMEW, eeZR], HeliR[SMEW, BOXR]};

FullTHDMHeliL = {HeliL[THDMEW, Gammatt], HeliL[THDMEW, Ztt], HeliL[THDMEW, ZZ], HeliL[THDMEW, GammaZ], HeliL[THDMEW, GammaGamma], HeliL[THDMEW, eeGammaL], HeliL[THDMEW, eeZL], HeliL[THDMEW, BOXL]};
FullTHDMHeliR = {HeliR[THDMEW, Gammatt], HeliR[THDMEW, Ztt], HeliR[THDMEW, ZZ], HeliR[THDMEW, GammaZ], HeliR[THDMEW, GammaGamma], HeliR[THDMEW, eeGammaR], HeliR[THDMEW, eeZR], HeliR[THDMEW, BOXR]};

FullMSSMHeliL = {HeliL[THDMEW, Gammatt], HeliL[THDMEW, Ztt], HeliL[THDMEW, ZZ], HeliL[THDMEW, GammaZ], HeliL[THDMEW, GammaGamma], HeliL[THDMEW, eeGammaL], HeliL[THDMEW, eeZL], HeliL[THDMEW, BOXL], HeliL[CharginoNeutralino, GammaGamma], HeliL[CharginoNeutralino, GammaZ], HeliL[CharginoNeutralino, ZZ], HeliL[Sfermion, GammaGamma], HeliL[Sfermion, GammaZ], HeliL[Sfermion, ZZ], HeliL[Chargino, Gammatt], HeliL[Chargino, Ztt], HeliL[Neutralino, Gammatt], HeliL[Neutralino, Ztt], HeliL[Neutralino, eeGammaL], HeliL[Neutralino, eeZL], HeliL[Chargino, eeGammaL], HeliL[Chargino, eeZL]};

FullMSSMHeliR = {HeliR[THDMEW, Gammatt], HeliR[THDMEW, Ztt], HeliR[THDMEW, ZZ], HeliR[THDMEW, GammaZ], HeliR[THDMEW, GammaGamma], HeliR[THDMEW, eeGammaR], HeliR[THDMEW, eeZR], HeliR[THDMEW, BOXR], HeliR[CharginoNeutralino, GammaGamma], HeliR[CharginoNeutralino, GammaZ], HeliR[CharginoNeutralino, ZZ], HeliR[Sfermion, GammaGamma], HeliR[Sfermion, GammaZ], HeliR[Sfermion, ZZ], HeliR[Chargino, Gammatt], HeliR[Chargino, Ztt], HeliR[Neutralino, Gammatt], HeliR[Neutralino, Ztt], HeliR[Neutralino, eeGammaR], HeliR[Neutralino, eeZR]};

(*rel. cross section corrections*)

FullSMDeltaC = {DeltaC[SMEW, Gammatt], DeltaC[SMEW, Ztt], DeltaC[SMEW, ZZ], DeltaC[SMEW, GammaZ], DeltaC[SMEW, GammaGamma], DeltaC[SMEW, eeGammaL], DeltaC[SMEW, eeGammaR], DeltaC[SMEW, eeZL],DeltaC[SMEW, eeZR], DeltaC[SMEW, BOXL], DeltaC[SMEW, BOXR]};
FullSMNoLFMsDeltaC = {DeltaC[SMEW, Gammatt], DeltaC[SMEW, Ztt], DeltaC[SMEWNoLFMs, ZZ], DeltaC[SMEWNoLFMs, GammaZ], DeltaC[SMEWNoLFMs, GammaGamma], DeltaC[SMEW, eeGammaL], DeltaC[SMEW, eeGammaR], DeltaC[SMEW, eeZL],DeltaC[SMEW, eeZR], DeltaC[SMEW, BOXL], DeltaC[SMEW, BOXR]};

FullTHDMDeltaC = {DeltaC[THDMEW, Gammatt], DeltaC[THDMEW, Ztt], DeltaC[THDMEW, ZZ], DeltaC[THDMEW, GammaZ], DeltaC[THDMEW, GammaGamma], DeltaC[THDMEW, eeGammaL], DeltaC[THDMEW, eeGammaR], DeltaC[THDMEW, eeZL], DeltaC[THDMEW, eeZR], DeltaC[THDMEW, BOXL], DeltaC[THDMEW, BOXR]};
FullTHDMNoLFMsDeltaC = {DeltaC[THDMEW, Gammatt], DeltaC[THDMEW, Ztt], DeltaC[THDMEWNoLFMs, ZZ], DeltaC[THDMEWNoLFMs, GammaZ], DeltaC[THDMEWNoLFMs, GammaGamma], DeltaC[THDMEW, eeGammaL], DeltaC[THDMEW, eeGammaR], DeltaC[THDMEW, eeZL], DeltaC[THDMEW, eeZR], DeltaC[THDMEW, BOXL], DeltaC[THDMEW, BOXR]};
FullTHDMNoLFMsMBNot0DeltaC = {DeltaC[THDMEW, Gammatt], DeltaC[THDMEW, Ztt], DeltaC[THDMEWNoLFMsMBNot0, ZZ], DeltaC[THDMEWNoLFMsMBNot0, GammaZ], DeltaC[THDMEWNoLFMsMBNot0, GammaGamma], DeltaC[THDMEW, eeGammaL], DeltaC[THDMEW, eeGammaR], DeltaC[THDMEW, eeZL], DeltaC[THDMEW, eeZR], DeltaC[THDMEW, BOXL], DeltaC[THDMEW, BOXR]};

(*without susy boxes!*)

FullMSSMDeltaCNoSUSYBox = {DeltaC[THDMEW, Gammatt], DeltaC[THDMEW, Ztt], DeltaC[THDMEW, ZZ], DeltaC[THDMEW, GammaZ], DeltaC[THDMEW, GammaGamma], DeltaC[THDMEW, eeGammaL], DeltaC[THDMEW, eeGammaR], DeltaC[THDMEW, eeZL], DeltaC[THDMEW, eeZR], DeltaC[THDMEW, BOXL], DeltaC[THDMEW, BOXR], DeltaC[CharginoNeutralino, GammaGamma], DeltaC[CharginoNeutralino, GammaZ], DeltaC[CharginoNeutralino, ZZ],DeltaC[Sfermion, GammaGamma], DeltaC[Sfermion, GammaZ], DeltaC[Sfermion, ZZ], DeltaC[Chargino, Gammatt], DeltaC[Chargino, Ztt], DeltaC[Neutralino, Gammatt], DeltaC[Neutralino, Ztt], DeltaC[Neutralino, eeGammaL], DeltaC[Neutralino, eeGammaR], DeltaC[Chargino, eeGammaL], DeltaC[Neutralino, eeZL], DeltaC[Neutralino, eeZR], DeltaC[Chargino, eeZL]};

FullMSSMDeltaC = {DeltaC[THDMEW, Gammatt], DeltaC[THDMEW, Ztt], DeltaC[THDMEW, ZZ], DeltaC[THDMEW, GammaZ], DeltaC[THDMEW, GammaGamma], DeltaC[THDMEW, eeGammaL], DeltaC[THDMEW, eeGammaR], DeltaC[THDMEW, eeZL], DeltaC[THDMEW, eeZR], DeltaC[THDMEW, BOXL], DeltaC[THDMEW, BOXR], DeltaC[CharginoNeutralino, GammaGamma], DeltaC[CharginoNeutralino, GammaZ], DeltaC[CharginoNeutralino, ZZ],DeltaC[Sfermion, GammaGamma], DeltaC[Sfermion, GammaZ], DeltaC[Sfermion, ZZ], DeltaC[Chargino, Gammatt], DeltaC[Chargino, Ztt], DeltaC[Neutralino, Gammatt], DeltaC[Neutralino, Ztt], DeltaC[Neutralino, eeGammaL], DeltaC[Neutralino, eeGammaR], DeltaC[Chargino, eeGammaL], DeltaC[Neutralino, eeZL], DeltaC[Neutralino, eeZR], DeltaC[Chargino, eeZL], DeltaC[DCCharginoBox, Extrapolation], DeltaC[DCNeutralinoBoxes, Extrapolation]};
FullMSSMNoLFMsDeltaC = {DeltaC[THDMEW, Gammatt], DeltaC[THDMEW, Ztt], DeltaC[THDMEWNoLFMs, ZZ], DeltaC[THDMEWNoLFMs, GammaZ], DeltaC[THDMEWNoLFMs, GammaGamma], DeltaC[THDMEW, eeGammaL], DeltaC[THDMEW, eeGammaR], DeltaC[THDMEW, eeZL], DeltaC[THDMEW, eeZR], DeltaC[THDMEW, BOXL], DeltaC[THDMEW, BOXR], DeltaC[CharginoNeutralino, GammaGamma], DeltaC[CharginoNeutralino, GammaZ], DeltaC[CharginoNeutralino, ZZ],DeltaC[Sfermion, GammaGamma], DeltaC[Sfermion, GammaZ], DeltaC[Sfermion, ZZ], DeltaC[Chargino, Gammatt], DeltaC[Chargino, Ztt], DeltaC[Neutralino, Gammatt], DeltaC[Neutralino, Ztt], DeltaC[Neutralino, eeGammaL], DeltaC[Neutralino, eeGammaR], DeltaC[Chargino, eeGammaL], DeltaC[Neutralino, eeZL], DeltaC[Neutralino, eeZR], DeltaC[Chargino, eeZL], DeltaC[DCCharginoBox, Extrapolation], DeltaC[DCNeutralinoBoxes, Extrapolation]};
FullMSSMNoLFMsMBNot0DeltaC = {DeltaC[THDMEW, Gammatt], DeltaC[THDMEW, Ztt], DeltaC[THDMEWNoLFMsMBNot0, ZZ], DeltaC[THDMEWNoLFMsMBNot0, GammaZ], DeltaC[THDMEWNoLFMsMBNot0, GammaGamma], DeltaC[THDMEW, eeGammaL], DeltaC[THDMEW, eeGammaR], DeltaC[THDMEW, eeZL], DeltaC[THDMEW, eeZR], DeltaC[THDMEW, BOXL], DeltaC[THDMEW, BOXR], DeltaC[CharginoNeutralino, GammaGamma], DeltaC[CharginoNeutralino, GammaZ], DeltaC[CharginoNeutralino, ZZ],DeltaC[Sfermion, GammaGamma], DeltaC[Sfermion, GammaZ], DeltaC[Sfermion, ZZ], DeltaC[Chargino, Gammatt], DeltaC[Chargino, Ztt], DeltaC[Neutralino, Gammatt], DeltaC[Neutralino, Ztt], DeltaC[Neutralino, eeGammaL], DeltaC[Neutralino, eeGammaR], DeltaC[Chargino, eeGammaL], DeltaC[Neutralino, eeZL], DeltaC[Neutralino, eeZR], DeltaC[Chargino, eeZL], DeltaC[DCCharginoBox, Extrapolation], DeltaC[DCNeutralinoBoxes, Extrapolation]};

tVertexSMDeltaC = {DeltaC[SMEW, Gammatt], DeltaC[SMEW, Ztt]};
eVertexSMDeltaC = {DeltaC[SMEW, eeGammaL], DeltaC[SMEW, eeGammaR], DeltaC[SMEW, eeZL], DeltaC[SMEW, eeZR]};
SESMDeltaC = {DeltaC[SMEW, ZZ], DeltaC[SMEW, GammaZ], DeltaC[SMEW, GammaGamma]};
BoxSMDeltaC = {DeltaC[SMEW, BOXL], DeltaC[SMEW, BOXR]};

tVertexTHDMDeltaC = {DeltaC[THDMEW, Gammatt], DeltaC[THDMEW, Ztt]};
eVertexTHDMDeltaC = eVertexSMDeltaC;
SETHDMDeltaC = {DeltaC[THDMEW, ZZ], DeltaC[THDMEW, GammaZ], DeltaC[THDMEW, GammaGamma]};
BoxTHDMDeltaC = BoxSMDeltaC;

tVertexGluinoDeltaC = {DeltaC[Gluino, Gammatt], DeltaC[Gluino, Ztt]};
tVertexChaDeltaC = {DeltaC[Chargino, Gammatt], DeltaC[Chargino, Ztt]};
tVertexNeuDeltaC = {DeltaC[Neutralino, Gammatt], DeltaC[Neutralino, Ztt]};
eVertexChaDeltaC = {DeltaC[Chargino, eeGammaL], DeltaC[Chargino, eeZL]};
eVertexNeuDeltaC = {DeltaC[Neutralino, eeGammaL], DeltaC[Neutralino, eeGammaR], DeltaC[Neutralino, eeZL], DeltaC[Neutralino, eeZR]};
SEChaNeuDeltaC = {DeltaC[CharginoNeutralino, GammaGamma], DeltaC[CharginoNeutralino, GammaZ], DeltaC[CharginoNeutralino, ZZ]};
SESfermionDeltaC = {DeltaC[Sfermion, GammaGamma], DeltaC[Sfermion, GammaZ], DeltaC[Sfermion, ZZ]};
QCDDeltaC = {DeltaC[QCD, Gammatt], DeltaC[QCD, Ztt]};

SEMSSMDeltaC = {DeltaC[THDMEW, ZZ], DeltaC[THDMEW, GammaZ], DeltaC[THDMEW, GammaGamma], DeltaC[CharginoNeutralino, ZZ], DeltaC[CharginoNeutralino, GammaZ], DeltaC[CharginoNeutralino, GammaGamma], DeltaC[Sfermion, ZZ], DeltaC[Sfermion, GammaZ], DeltaC[Sfermion, GammaGamma]};

End[];




