(*Needs["TQPAT`"];*)
Get["../TQPAT.m"];

(*================================================================================*)
(*                       Setting SM Parameters                                    *)
(*================================================================================*)
TopQuarkMass=173.3;
ZBosonMass = 91.1876;
WBosonMass = 80.399;
BottomQuarkMass=4.67;
CWValue = WBosonMass/ZBosonMass;
AlfaValue =1/(137.036);
AlfasValue = 0.108;

DeltaAlphaHad5=277.45*10^(-4);
DeltaAlphaLep=(314.19 +0.78)*10^(-4);

(*
Plz note that the MSSM box contribution cannot be evaluated for exactly vanishing electron mass (VanishingMassSquared=0) due to the numerical integration method.
Thus we keep a small value for the light fermion masses as regulator. 
*)
VanishingMassSquared=10^(-7);


UserDefinedSMParameters={MT2 -> TopQuarkMass^2,MB2 ->BottomQuarkMass^2,MS2->VanishingMassSquared,MU2->VanishingMassSquared,MD2->VanishingMassSquared,MC2->VanishingMassSquared,ME2->VanishingMassSquared,MM2->VanishingMassSquared,ML2->VanishingMassSquared, MW2 -> WBosonMass^2, MZ2 -> ZBosonMass^2, SW2 -> (1 - CWValue^2),CW2 -> CWValue^2,Alfa->AlfaValue,Alfas->AlfasValue};


(*Calculating SigmaGamma[exp,had5] and SigmaGamma[exp,lep] with DeltaAlphaHadronic5 and DeltaAlphaLeptonic using the given Z-Boson mass.*)
SetDeltaAlpha[DeltaAlphaHadronic5AtMZ->DeltaAlphaHad5,DeltaAlphaLeptonicAtMZ->DeltaAlphaLep,MZ->ZBosonMass];





(*================================================================================*)
(*                    Calculating MA slope                                        *)
(*================================================================================*)


(*Defining DataSet*)
(*Setting Path Option for DisplayDataSets will automaticly set standard Path option of LoadDataSet, SaveDataSet and DeleteDataSetFile to the same value.*)
SetOptions[DisplayDataSets,Path->($TQPATDir<>"/examples/datasets")];

LoadDataSet["LightStopTB20DataSet"]
LighStopTB20SpecialSMParasDataSet=ReplaceValuesInDataSet[LightStopTB20DataSet,UserDefinedSMParameters];

(*SQCD*)
CreateDataSetResults[tVertexGluinoDeltaC, LighStopTB20SpecialSMParasDataSet];
SaveDataSetResults[tVertexGluinoDeltaC, LighStopTB20SpecialSMParasDataSet];

(*SM*)
CreateDataSetResults[FullSMNoLFMsDeltaC, LighStopTB20SpecialSMParasDataSet];
SaveDataSetResults[FullSMNoLFMsDeltaC, LighStopTB20SpecialSMParasDataSet];


(* MSSM including THDM *)
(*Comment this in in order to calculate the MSSM results from scratch.*)
(*Note this will take some time!                                      *)

CreateDataSetResults[FullMSSMNoLFMsDeltaC, LighStopTB20SpecialSMParasDataSet];
SaveDataSetResults[FullMSSMNoLFMsDeltaC, LighStopTB20SpecialSMParasDataSet];


(*(*The following replaces the skipped calculation above*)
LoadDataSetResults[FullSMNoLFMsDeltaC, LighStopTB20SpecialSMParasDataSet];
LoadDataSetResults[FullMSSMNoLFMsDeltaC, LighStopTB20SpecialSMParasDataSet];*)

(*Recalculating the VB SE contributions in the THDM with MB!=0*)
CreateDataSetResults[{DeltaC[THDMEWNoLFMsMBNot0, ZZ],DeltaC[THDMEWNoLFMsMBNot0, GammaZ],DeltaC[THDMEWNoLFMsMBNot0, GammaGamma]}, LighStopTB20SpecialSMParasDataSet];


(*================================================================================*)
(*                     Creation Data Tables                                       *)
(*================================================================================*)

FullSMDeltaCTable=Table[{x,CalcInterpolation[FullSMNoLFMsDeltaC, LighStopTB20SpecialSMParasDataSet][x]},{x,150,500,10}];
FullTHDMDeltaCTable=Table[{x,CalcInterpolation[FullTHDMNoLFMsDeltaC, LighStopTB20SpecialSMParasDataSet][x]},{x,150,500,10}];
FullMSSMDeltaCTable=Table[{x,CalcInterpolation[FullMSSMNoLFMsDeltaC, LighStopTB20SpecialSMParasDataSet][x]},{x,150,500,10}];

Export[$TQPATDir <> "/examples/tables/LightStopTB20FullSMDeltaC.tbl", FullSMDeltaCTable,"Table"];
Export[$TQPATDir <> "/examples/tables/LightStopTB20FullTHDMDeltaC.tbl", FullTHDMDeltaCTable,"Table"];
Export[$TQPATDir <> "/examples/tables/LightStopTB20FullMSSMDeltaC.tbl", FullMSSMDeltaCTable,"Table"];

(*================================================================================*)
(*                     Creation of DeltaC Plots                                   *)
(*================================================================================*)

TQPATSolid = AbsoluteDashing[{1, 0}];
TQPATDotDashed = AbsoluteDashing[{0.1, 6, 5, 6}];
TQPATDotted = AbsoluteDashing[{0.1, 5}];
TQPATDashed = AbsoluteDashing[{7, 7}];

LableListInput = {{Style["SM", Black, Italic, 18], {Black, TQPATSolid,Thick}},{Style["THDM", Darker[Blue], Italic, 18], {Darker[Blue], TQPATDashed, Thick}}, {Style["MSSM", Red, Italic, 18], {Red, Thick, TQPATDotted}}};

LightStop150to500TB20DeltaC = Show[Plot[{CalcInterpolation[FullSMNoLFMsDeltaC, LighStopTB20SpecialSMParasDataSet][x], 
                                         CalcInterpolation[FullTHDMNoLFMsDeltaC, LighStopTB20SpecialSMParasDataSet][x],
                                         CalcInterpolation[FullMSSMNoLFMsDeltaC, LighStopTB20SpecialSMParasDataSet][x]}, {x, 150, 500},
     Frame -> True,
     AxesOrigin -> {150, 0.09},
     FrameLabel -> {Style["\!\(\*SubscriptBox[\"M\",\"A\"]\)(GeV)", 18], Style["\!\(\*SuperscriptBox[\"\[CapitalDelta]\", \"EW\"]\)",  18]},
     ImageSize -> 500,
     PlotStyle -> (#[[2]] & /@ LableListInput),
     LabelStyle -> Directive[Italic],
     FrameStyle -> 16,
     PlotRange -> {{150,500},{0.14,0.15}}
     ],
 DrawLegend[{
         {Style["light \!\(\*OverscriptBox[\(t\), \(~\)]\)",Black, Italic, 17], {Black, Thin}},
         {Style["tan\[Beta]=20", Black, Italic, 17], {Blue, CustomDashed, Thick}}
       },
      SkipLinesTab -> True,
      LegendPosition -> {165, 0.148},
      LegendSize -> {20, 0.002},
      TextSpace -> 0.6,
      LineSpace -> 0.3],
  DrawLegend[LableListInput,
   LegendFrame -> False,
   LegendFrameStyle -> {AbsoluteDashing[{1, 1}], Black},
   LegendPosition -> {400, 0.141},
   LegendSize -> {80, 0.0030},
   LayoutBoxes -> False,
   TextSpace -> 0.6,
   LineSpace -> 0.4,
   TextOffset -> {0.0, 0.0},
   LineOffset -> {0.0, 0.0},
   LineLength -> 0.7]
];

(Export[$TQPATDir <> "/examples/pics/"<>#<>".eps",ToExpression[#]];
 Export[$TQPATDir <> "/examples/pics/"<>#<>".pdf",ToExpression[#]];)&/@{"LightStop150to500TB20DeltaC"};

