Needs["TQPAT`"];

(*================================================================================*)
(*                       Setting SM Parameters                                    *)
(*================================================================================*)
TopQuarkMass=173.3;
BottomQuarkMass=4.2;
WBosonMass = 80.40;
ZBosonMass = 91.1876;
CWValue = WBosonMass/ZBosonMass;
AlfaValue =1/(137.036);
AlfasValue = 0.108;
DeltaAlphaHad5=277.45*10^(-4);
DeltaAlphaLep=(314.19 +0.78)*10^(-4);

(*
Plz note that the MSSM box contribution cannot be evaluated for exactly vanishing electron mass (VanishingMassSquared=0) due to the numerical integration method.
Thus we keep a small value for the light fermion masses as regulator. 
*)
VanishingMassSquared=10^(-7);

UserDefinedSMParameters={MT2 -> TopQuarkMass^2,MB2 ->BottomQuarkMass^2,MS2->VanishingMassSquared,MU2->VanishingMassSquared,MD2->VanishingMassSquared,MC2->VanishingMassSquared,ME2->VanishingMassSquared,MM2->VanishingMassSquared,ML2->VanishingMassSquared, MW2 -> WBosonMass^2, MZ2 -> ZBosonMass^2, SW2 -> (1 - CWValue^2),CW2 -> CWValue^2,Alfa->AlfaValue,Alfas->AlfasValue};

(*Calculating SigmaGamma[exp,had5] and SigmaGamma[exp,lep] with DeltaAlphaHadronic5 and DeltaAlphaLeptonic using the given Z-Boson mass.*)
SetDeltaAlpha[DeltaAlphaHadronic5AtMZ->DeltaAlphaHad5,DeltaAlphaLeptonicAtMZ->DeltaAlphaLep,MZ->ZBosonMass];



(*================================================================================*)
(*            Creation of the SM, MSSM THDM DeltaC Table                          *)
(*================================================================================*)

LoadDataSet["SPSPointsDataSet"]
SPSPointsSpecialSMParasDataSet=ReplaceValuesInDataSet[SPSPointsDataSet,UserDefinedSMParameters];

CorrectionNames = {" ", "\!\(\*SuperscriptBox[\"\[CapitalDelta]\", \"SM\"]\)","\!\(\*SuperscriptBox[\"\[CapitalDelta]\",\"THDM\"]\)", "\!\(\*SuperscriptBox[\"\[CapitalDelta]\", \"MSSM\"]\)"};
SPSLabels = {"SPS1a", "SPS1a'", "SPS1b", "SPS2", "SPS3", "SPS4", "SPS5"};
ModelListMBNot0 = {FullSMNoLFMsDeltaC, FullTHDMNoLFMsMBNot0DeltaC, FullMSSMNoLFMsMBNot0DeltaC};


DeltaCModelMBNot0Table = Transpose[Prepend[Transpose[Prepend[(#[[2]] & /@ DoAllNumerics[#, SPSPointsSpecialSMParasDataSet]) & /@ ModelListMBNot0, SPSLabels]], CorrectionNames]];

CreateDirectory[$TQPATDir <> "/examples/tables"];
Export[$TQPATDir <> "/examples/tables/DeltaCModelMBNot0Table.tbl",DeltaCModelMBNot0Table,"Table"];


(*Neglecting the bottom quark mass in THDM VB SEs*)
ModelListMB0 = {FullSMNoLFMsDeltaC, FullTHDMNoLFMsDeltaC, FullMSSMNoLFMsDeltaC};

DeltaCModelMB0Table = Transpose[Prepend[Transpose[Prepend[(#[[2]] & /@ DoAllNumerics[#, SPSPointsSpecialSMParasDataSet]) & /@ ModelListMB0, SPSLabels]], CorrectionNames]];

CreateDirectory[$TQPATDir <> "/examples/tables"];
Export[$TQPATDir <> "/examples/tables/DeltaCModelMB0Table.tbl",DeltaCModelMB0Table,"Table"];



(*================================================================================*)
(*                    Calculating SPS1 Slope Data                                 *)
(*================================================================================*)
(*Defining DataSet*)
LoadDataSet["SPS1100to350DataSet"];
SPS1100to350SpecialSMParasDataSet=ReplaceValuesInDataSet[SPS1100to350DataSet,UserDefinedSMParameters];

(*SQCD*)
CreateDataSetResults[tVertexGluinoDeltaC, SPS1100to350SpecialSMParasDataSet];
SaveDataSetResults[tVertexGluinoDeltaC, SPS1100to350SpecialSMParasDataSet];

(*SM*)
CreateDataSetResults[FullSMNoLFMsDeltaC, SPS1100to350SpecialSMParasDataSet];
SaveDataSetResults[FullSMNoLFMsDeltaC, SPS1100to350SpecialSMParasDataSet];


(*MSSM including THDM*)
(*Comment this in in order to calculate the MSSM results from scratch.*)
(*Note this will take some time!                                      *)

(*CreateDataSetResults[FullMSSMNoLFMsDeltaC, SPS1100to350SpecialSMParasDataSet];
SaveDataSetResults[FullMSSMNoLFMsDeltaC, SPS1100to350SpecialSMParasDataSet];*)

(*The following replaces the skipped calculation above*)

LoadDataSetResults[FullMSSMNoLFMsDeltaC, SPS1100to350SpecialSMParasDataSet];


(*Recalculating the VB SE contributions in the THDM with MB!=0*)
CreateDataSetResults[{DeltaC[THDMEWNoLFMsMBNot0, ZZ],DeltaC[THDMEWNoLFMsMBNot0, GammaZ],DeltaC[THDMEWNoLFMsMBNot0, GammaGamma]}, SPS1100to350SpecialSMParasDataSet];
SaveDataSetResults[{DeltaC[THDMEWNoLFMsMBNot0, ZZ],DeltaC[THDMEWNoLFMsMBNot0, GammaZ],DeltaC[THDMEWNoLFMsMBNot0, GammaGamma]}, SPS1100to350SpecialSMParasDataSet];




(*================================================================================*)
(*                    Calculating SPS2 Slope Data                                 *)
(*================================================================================*)
(*Defining DataSet*)
LoadDataSet["SPS2150to400DataSet"];
SPS2150to400SpecialSMParasDataSet=ReplaceValuesInDataSet[SPS2150to400DataSet,UserDefinedSMParameters];

(*SQCD*)
CreateDataSetResults[tVertexGluinoDeltaC, SPS2150to400SpecialSMParasDataSet];
SaveDataSetResults[tVertexGluinoDeltaC, SPS2150to400SpecialSMParasDataSet];

(*SM*)
CreateDataSetResults[FullSMNoLFMsDeltaC, SPS2150to400SpecialSMParasDataSet];
SaveDataSetResults[FullSMNoLFMsDeltaC, SPS2150to400SpecialSMParasDataSet];

(*MSSM including THDM*)
(*Comment this in in order to calculate the MSSM results from scratch.*)
(*Note this will take some time!*)

(*CreateDataSetResults[FullMSSMNoLFMsDeltaC, SPS2150to400SpecialSMParasDataSet];
SaveDataSetResults[FullMSSMNoLFMsDeltaC, SPS2150to400SpecialSMParasDataSet];*)

(*The following replaces the skipped calculation above*)

LoadDataSetResults[FullMSSMNoLFMsDeltaC, SPS2150to400SpecialSMParasDataSet];


(*Recalculating the VB SE contributions in the THDM with MB!=0*)
CreateDataSetResults[{DeltaC[THDMEWNoLFMsMBNot0, ZZ],DeltaC[THDMEWNoLFMsMBNot0, GammaZ],DeltaC[THDMEWNoLFMsMBNot0, GammaGamma]}, SPS2150to400SpecialSMParasDataSet];
SaveDataSetResults[{DeltaC[THDMEWNoLFMsMBNot0, ZZ],DeltaC[THDMEWNoLFMsMBNot0, GammaZ],DeltaC[THDMEWNoLFMsMBNot0, GammaGamma]}, SPS2150to400SpecialSMParasDataSet];





(*================================================================================*)
(*                     Creation of DeltaC Plots                                   *)
(*================================================================================*)

TQPATSolid = AbsoluteDashing[{1, 0}];
TQPATDotDashed = AbsoluteDashing[{0.1, 6, 5, 6}];
TQPATDotted = AbsoluteDashing[{0.1, 5}];
TQPATDashed = AbsoluteDashing[{7, 7}];

LableListInput = {{Style["SM", Black, Italic, 18], {Black, TQPATSolid,Thick}},{Style["THDM", Darker[Blue], Italic, 18], {Darker[Blue], TQPATDashed, Thick}}, {Style["MSSM", Red, Italic, 18], {Red, Thick, TQPATDotted}}};

SPS1100to350FullDeltaC = Show[Plot[{CalcInterpolation[FullSMNoLFMsDeltaC, SPS1100to350SpecialSMParasDataSet][x], CalcInterpolation[FullTHDMNoLFMsDeltaC, SPS1100to350SpecialSMParasDataSet][x],CalcInterpolation[FullMSSMNoLFMsDeltaC, SPS1100to350SpecialSMParasDataSet][x]}, {x, 100, 350},
     Frame -> True,
     AxesOrigin -> {100, 0.09},
     FrameLabel -> {Style["\!\(\*SubscriptBox[\"m\",RowBox[{\"1\", \"/\", \"2\"}]]\)(GeV)", 18], Style["\!\(\*SuperscriptBox[\"\[CapitalDelta]\", \"EW\"]\)",  18]},
     ImageSize -> 500,
     PlotStyle -> (#[[2]] & /@ LableListInput),
     LabelStyle -> Directive[Italic],
     FrameStyle -> 16,
     PlotRange -> Automatic
     ],
  DrawLegend[LableListInput,
   LegendFrame -> False,
   LegendFrameStyle -> {AbsoluteDashing[{1, 1}], Black},
   LegendPosition -> {250, 0.115},
   LegendSize -> {80, 0.025},
   LayoutBoxes -> False,
   TextSpace -> 0.6,
   LineSpace -> 0.4,
   TextOffset -> {0.0, 0.0},
   LineOffset -> {0.0, 0.0},
   LineLength -> 0.7]
];

SPS2150to400FullDeltaC = Show[Plot[{ CalcInterpolation[FullSMNoLFMsDeltaC, SPS2150to400SpecialSMParasDataSet][x], CalcInterpolation[FullTHDMNoLFMsDeltaC, SPS2150to400SpecialSMParasDataSet][x],CalcInterpolation[FullMSSMNoLFMsDeltaC, SPS2150to400SpecialSMParasDataSet][x]}, {x, 150, 400},
     Frame -> True,
     AxesOrigin -> {150, 0.08},
     FrameLabel -> {Style["\!\(\*SubscriptBox[\"m\",RowBox[{\"1\", \"/\", \"2\"}]]\)(GeV)", 18], Style["\!\(\*SuperscriptBox[\"\[CapitalDelta]\", \"EW\"]\)",  18]},
     ImageSize -> 500,
     PlotStyle -> (#[[2]] & /@ LableListInput),
     LabelStyle -> Directive[Italic],
     FrameStyle -> 16,
     PlotRange -> {{150,400},{0.12,0.19}}
     ],
  DrawLegend[LableListInput, 
   LegendFrame -> False,
   LegendFrameStyle -> {AbsoluteDashing[{1, 1}], Black},
   LegendPosition -> {320, 0.165},
   LegendSize -> {80, 0.025},
   LayoutBoxes -> False,
   TextSpace -> 0.6,
   LineSpace -> 0.4,
   TextOffset -> {0.0, 0.0},
   LineOffset -> {0.0, 0.0},
   LineLength -> 0.7]
];

LableListInput = {{Style["\!\(\*SuperscriptBox[\"\[Chi]\", \"\[PlusMinus]\"]\)", Red, Italic, 20], {Red, Thick, TQPATDashed}},{Style["\!\(\*SuperscriptBox[\"\[Chi]\", \"0\"]\)", Orange, Italic, 20], {Orange, Thick}}};

SPS1100to350eVertexDeltaC = Show[Plot[{CalcInterpolation[eVertexChaDeltaC, SPS1100to350SpecialSMParasDataSet][x], CalcInterpolation[eVertexNeuDeltaC, SPS1100to350SpecialSMParasDataSet][x]}, {x, 100, 350},
     Frame -> True,
     AxesOrigin -> {100, 0},
     PlotRange -> {-0.01, 0.01},
     FrameLabel -> {Style["\!\(\*SubscriptBox[\"m\", RowBox[{\"1\", \"/\", \"2\"}]]\)(GeV)", 18], Style["\!\(\*SubsuperscriptBox[\"\[CapitalDelta]\", SubscriptBox[\"V\", \"e\"], \"EW\"]\)", 18]},
     ImageSize -> 500,
     PlotStyle -> (#[[2]] & /@ LableListInput),
     LabelStyle -> Directive[Italic],
     FrameStyle -> 16,
     PlotRange -> Automatic
     ],
  DrawLegend[LableListInput, 
   LegendFrame -> False,
   LegendFrameStyle -> {AbsoluteDashing[{1, 1}], Black},
   LegendPosition -> {270, -0.008},
   LegendSize -> {80, 0.005},
   LayoutBoxes -> False,
   TextSpace -> 0.6,
   LineSpace -> 0.4,
   TextOffset -> {0.0, 0.0},
   LineOffset -> {0.0, 0.0},
   LineLength -> 0.7]
 ];


LableListInput = {{Style["\!\(\*SuperscriptBox[\"\[Chi]\", \"0\"]\)+\!\(\*SuperscriptBox[\"\[Chi]\", \"\[PlusMinus]\"]\)", Red, Italic, 20], {Red, Thick, TQPATDotted}},{Style["\!\(\*OverscriptBox[\"f\", \"~\"]\)", Darker[Purple], Italic, 20],  {Darker[Purple], Thick}}};

SPS1100to350SUSYSEDeltaC = 
 Show[Plot[{CalcInterpolation[SEChaNeuDeltaC, SPS1100to350SpecialSMParasDataSet][x], CalcInterpolation[SESfermionDeltaC, SPS1100to350SpecialSMParasDataSet][x]}, {x, 100, 350},
     Frame -> True,
     AxesOrigin -> {100, 0},
     PlotRange -> {-0.01, 0.01},
     FrameLabel -> {Style["\!\(\*SubscriptBox[\"m\",RowBox[{\"1\", \"/\", \"2\"}]]\)(GeV)", 18], Style["\!\(\*SubsuperscriptBox[\"\[CapitalDelta]\", \"SE\", \"EW\"]\)", 18]},
     ImageSize -> 500,
     PlotStyle -> (#[[2]] & /@ LableListInput),
     LabelStyle -> Directive[Italic],
     FrameStyle -> 16,
     PlotRange -> Automatic
     ],
  DrawLegend[LableListInput,
   LegendFrame -> False,
   LegendFrameStyle -> {AbsoluteDashing[{1, 1}], Black},
   LegendPosition -> {270, 0.0025},
   LegendSize -> {80, 0.005},
   LayoutBoxes -> False,
   TextSpace -> 0.6,
   LineSpace -> 0.4,
   TextOffset -> {0.0, 0.0},
   LineOffset -> {0.0, 0.0},
   LineLength -> 0.7]
  ];

LableListInput = {{Style["\!\(\*SuperscriptBox[\"\[Chi]\", \"\[PlusMinus]\"]\)", Red, Italic, 20], {Red, Thick, TQPATDashed}},{Style["\!\(\*SuperscriptBox[\"\[Chi]\", \"0\"]\)", Orange, Italic, 20],  {Orange, Thick}}};

SPS1100to350SUSYBoxDeltaC = Show[Plot[{CalcInterpolation[{DeltaC[DCCharginoBox, Extrapolation]}, SPS1100to350SpecialSMParasDataSet][x], CalcInterpolation[{DeltaC[DCNeutralinoBoxes, Extrapolation]}, SPS1100to350SpecialSMParasDataSet][x]}, {x, 100, 350},
     Frame -> True,
     AxesOrigin -> {100, 0},
     PlotRange -> {-0.01, 0.01},
     FrameLabel -> {Style["\!\(\*SubscriptBox[\"m\", RowBox[{\"1\", \"/\", \"2\"}]]\)(GeV)", 18], Style["\!\(\*SubsuperscriptBox[\"\[CapitalDelta]\", \"Box\", \"EW\"]\)", 18]},
     ImageSize -> 500,
     PlotStyle -> (#[[2]] & /@ LableListInput),
     LabelStyle -> Directive[Italic],
     FrameStyle -> 16,
     PlotRange -> Automatic
     ],
  DrawLegend[LableListInput,
   LegendFrame -> False,
   LegendFrameStyle -> {AbsoluteDashing[{1, 1}], Black},
   LegendPosition -> {270, 0.0025},
   LegendSize -> {80, 0.005},
   LayoutBoxes -> False,
   TextSpace -> 0.6,
   LineSpace -> 0.4,
   TextOffset -> {0.0, 0.0},
   LineOffset -> {0.0, 0.0},
   LineLength -> 0.7]
  ];

LableListInput = {{Style["\!\(\*SuperscriptBox[\"\[Chi]\", \"\[PlusMinus]\"]\)", Red, Italic, 20], {Red, Thick, TQPATDashed}},{Style["\!\(\*SuperscriptBox[\"\[Chi]\", \"0\"]\)", Orange, Italic, 20],  {Orange, Thick, TQPATSolid}},{Style["\!\(\*OverscriptBox[\"g\", \"~\"]\)", Darker[Green], Italic, 20], {Darker[Green], TQPATDotDashed, Thick}}};

SPS1100to350SUSYtVertexDeltaC = Show[Plot[{CalcInterpolation[tVertexChaDeltaC, SPS1100to350SpecialSMParasDataSet][x], CalcInterpolation[tVertexNeuDeltaC, SPS1100to350SpecialSMParasDataSet][x], CalcInterpolation[tVertexGluinoDeltaC, SPS1100to350SpecialSMParasDataSet][x]}, {x, 100, 350},
     Frame -> True,
     AxesOrigin -> {100, 0},
     PlotRange -> {-0.01, 0.01},
     FrameLabel -> {Style["\!\(\*SubscriptBox[\"m\", RowBox[{\"1\", \"/\", \"2\"}]]\)(GeV)", 18], Style["\!\(\*SubsuperscriptBox[\"\[CapitalDelta]\", SubscriptBox[\"V\", \"t\"], \"EW\"]\)", 18]},
     ImageSize -> 500,
     PlotStyle -> (#[[2]] & /@ LableListInput),
     LabelStyle -> Directive[Italic],
     FrameStyle -> 16,
     PlotRange -> Automatic
     ],
  DrawLegend[LableListInput,
   LegendFrame -> False,
   LegendFrameStyle -> {AbsoluteDashing[{1, 1}], Red},
   LegendPosition -> {270, -0.008},
   LegendSize -> {80, 0.005*3/2},
   LayoutBoxes -> False,
   TextSpace -> 0.6,
   LineSpace -> 0.4,
   TextOffset -> {0.0, 0.0},
   LineOffset -> {0.0, 0.0},
   LineLength -> 0.7]
  ];

(Export[$TQPATDir <> "/examples/pics/"<>#<>".eps",ToExpression[#]];)&/@{"SPS1100to350FullDeltaC","SPS2150to400FullDeltaC","SPS1100to350eVertexDeltaC","SPS1100to350SUSYSEDeltaC","SPS1100to350SUSYBoxDeltaC","SPS1100to350SUSYtVertexDeltaC"};


