(*Needs["TQPAT`"];*)
Get["../TQPAT.m"];

(*================================================================================*)
(*                       Setting SM Parameters                                    *)
(*================================================================================*)
TopQuarkMass=173.3;
ZBosonMass = 91.1876;
WBosonMass = 80.399;
BottomQuarkMass=4.67;
CWValue = WBosonMass/ZBosonMass;
AlfaValue =1/(137.036);
AlfasValue = 0.097(* taken from a separate calculation and kept fixed,
because we need only tree level alpha_s here*);

DeltaAlphaHad5=277.45*10^(-4);
DeltaAlphaLep=(314.19 +0.78)*10^(-4);

(*
Plz note that the MSSM box contribution cannot be evaluated for exactly vanishing electron mass (VanishingMassSquared=0) due to the numerical integration method.
Thus we keep a small value for the light fermion masses as regulator. 
*)
VanishingMassSquared=10^(-7);


UserDefinedSMParameters={MT2 -> TopQuarkMass^2,MB2 ->BottomQuarkMass^2,MS2->VanishingMassSquared,MU2->VanishingMassSquared,MD2->VanishingMassSquared,MC2->VanishingMassSquared,ME2->VanishingMassSquared,MM2->VanishingMassSquared,ML2->VanishingMassSquared, MW2 -> WBosonMass^2, MZ2 -> ZBosonMass^2, SW2 -> (1 - CWValue^2),CW2 -> CWValue^2,Alfa->AlfaValue,Alfas->AlfasValue};


(*Calculating SigmaGamma[exp,had5] and SigmaGamma[exp,lep] with DeltaAlphaHadronic5 and DeltaAlphaLeptonic using the given Z-Boson mass.*)
SetDeltaAlpha[DeltaAlphaHadronic5AtMZ->DeltaAlphaHad5,DeltaAlphaLeptonicAtMZ->DeltaAlphaLep,MZ->ZBosonMass];





(*================================================================================*)
(*                    Calculating mtildet slope                                   *)
(*================================================================================*)


(*Defining DataSet*)
(*Setting Path Option for DisplayDataSets will automaticly set standard Path option of LoadDataSet, SaveDataSet and DeleteDataSetFile to the same value.*)
SetOptions[DisplayDataSets,Path->($TQPATDir<>"/examples/datasets")];

LoadDataSet["ModMhMaxDataSet"]
ModMhMaxSpecialSMParasDataSet=ReplaceValuesInDataSet[ModMhMaxDataSet,UserDefinedSMParameters];

(*SQCD*)
CreateDataSetResults[tVertexGluinoDeltaC, ModMhMaxSpecialSMParasDataSet];
SaveDataSetResults[tVertexGluinoDeltaC, ModMhMaxSpecialSMParasDataSet];

(*================================================================================*)
(*                     Creation Data Tables                                       *)
(*================================================================================*)

SQCDDeltaCTable=Table[{x,CalcInterpolation[tVertexGluinoDeltaC, ModMhMaxSpecialSMParasDataSet][x]},{x,350,1000,50}];

Export[$TQPATDir <> "/examples/tables/ModMhMaxSQCDDeltaC.tbl", SQCDDeltaCTable,"Table"];


(*================================================================================*)
(*                     Creation of DeltaC Plots                                   *)
(*================================================================================*)

TQPATSolid = AbsoluteDashing[{1, 0}];

LableListInput = {{Style["SQCD", Black, Italic, 18], {Black, TQPATSolid,Thick}}};

ModMhMaxSUSYQCDDeltaC = Show[Plot[{100*CalcInterpolation[tVertexGluinoDeltaC, ModMhMaxSpecialSMParasDataSet][x]}, {x, 350, 1000},
     Frame -> True,
     AxesOrigin -> {350, 0},
     PlotRange -> {-0.06, -0.02},
     FrameLabel -> {Style["\!\(\*SubscriptBox[OverscriptBox[\"m\", \"~\"], \"t\"]\)(GeV)", 18], 
                    Style["\!\(\*SuperscriptBox[\"\[CapitalDelta]\", \"SQCD\"]\)(%)", 18]},
     ImageSize -> 500,
     PlotStyle -> (#[[2]] & /@ LableListInput),
     LabelStyle -> Directive[Italic],
     FrameStyle -> 16,
     PlotRange -> Automatic
     ],
(*  DrawLegend[LableListInput,
   LegendFrame -> False,
   LegendFrameStyle -> {AbsoluteDashing[{1, 1}], Red},
   LegendPosition -> {350, -0.0005},
   LegendSize -> {300, 0.0005},
   LayoutBoxes -> False,
   TextSpace -> 0.6,
   LineSpace -> 0.4,
   TextOffset -> {0.0, 0.0},
   LineOffset -> {0.0, 0.0},
   LineLength -> 0.7],*)
 DrawLegend[{
       {Style["mod \*SubsuperscriptBox[\(m\), \(h\), \(max\)](+)", Black, Italic, 17], {Black, Thin}},
       {Style["\!\(\*SubscriptBox[\"A\", \"t\"]\)=1.5TeV", Black, Italic, 17], {Black, Thin}},
       {Style["tan\[Beta]=20", Black, Italic, 17], {Blue, TQPATSolid, Thick}},
       {Style["\!\(\*SubscriptBox[\"M\", \"A\"]\)=1TeV", Black, Italic, 17], {Blue, TQPATSolid, Thick}}},
      SkipLinesTab -> True,
      LegendPosition -> {410, -0.037},
      LegendSize -> {20, 0.015},
      TextSpace -> 0.6,
      LineSpace -> 0.3]
  ];
  
(Export[$TQPATDir <> "/examples/pics/"<>#<>".eps",ToExpression[#]];
 Export[$TQPATDir <> "/examples/pics/"<>#<>".pdf",ToExpression[#]];)&/@{"ModMhMaxSUSYQCDDeltaC"};


