Needs["TQPAT`"];

TopQuarkMass = 173.1;
WBosonMass = 80.40;
ZBosonMass = 91.1876;
CWValue = WBosonMass/ZBosonMass;
AlfasValue = 0.108;


(*
Creating the Data set for the simplified SUSYQCD scenario where both stop quarks and the gluino have the same mass MSUSY.
That means the mixing matrix is given by the unit matrix.
Thus any dependence on the mixing angle has to drop out.
*)
PreSimplifiedSUSYQCDDataSet = {SimpleSUSYQCD, {MT2 -> TopQuarkMass^2, Alfas -> AlfasValue, MSUSY2 -> TopQuarkMass^2}};
SimplifiedSUSYQCDDataSet = CreateSimpleDataSet[PreSimplifiedSUSYQCDDataSet, {MSUSY2 -> x^2}, VariableParameter -> x, ParameterMin -> TopQuarkMass, ParameterMax -> 400, NumberOfPoints -> 26];

(*The automatic cancelation of the mixing angle serves as welcome check for the results*)
SimplifiedDeltaCGluinoExact = Collect[PluginRealSfermionMixingMatrix[(2*Contribution[Gluino, Gammatt]) /. {MSf2[a___] :> MSUSY2, MSt12 -> MSUSY2, MSt22 -> MSUSY2, MGl2 -> MSUSY2}], {A0[m_], B0[m___], DB0[m___]}, Simplify];
Print["Exact result for DeltaC(Gluino) in the simplified scenario:"];
Print[SimplifiedDeltaCGluinoExact];

(*Expanding the exact result in MT2 over MSUSY2 up to order (MT2/MSUSY2)^5*)
SimplifiedDeltaCGluinoExpanded = KeepPower[ExpressPaVeFunctions[SimplifiedDeltaCGluinoExact, Expanded], MT2, 5];
Print["Expanded result for DeltaC(Gluino) in the simplified scenario:"];
Print[SimplifiedDeltaCGluinoExpanded];

(*Calculating numeric values for both expressions at one run using AddUpAllContributions -> False and the Direct invironment*)
SimplifiedSUSYQCDResults = DoAllNumerics[{Direct[SimplifiedDeltaCGluinoExact, tVertexNumerics], Direct[SimplifiedDeltaCGluinoExpanded, tVertexNumerics]}, SimplifiedSUSYQCDDataSet, AddUpAllContributions -> False];


(*Finaly plotting the results*)

MSUSYQCDPlot = Plot[{Interpolation[SimplifiedSUSYQCDResults[[1]]][x], Interpolation[SimplifiedSUSYQCDResults[[2]]][x]}, {x, TopQuarkMass, 400}, 
  Frame -> True, AxesOrigin -> {TopQuarkMass, 0}, 
  FrameLabel -> {Style["\!\(\*SubscriptBox[\"m\", \"SUSY\"]\)(GeV)", 18], Style["\!\(\*SuperscriptBox[\"\[CapitalDelta]\",\"SQCD\"]\)(\!\(\*SubscriptBox[\"m\", \"SUSY\"]\))" , 18]}, 
  ImageSize -> 500, 
  PlotStyle -> {{Black, Thick}, {Black, Dashed}}, 
  LabelStyle -> Directive[Italic], FrameStyle -> 16, 
  PlotRange -> {0, 0.006}];

Export[$TQPATDir <> "/examples/pics/DeltaSUSYQCDMSUSYMTeq"<>ToString[TopQuarkMass]<>"Alfaseq"<>ToString[AlfasValue]<>".eps",MSUSYQCDPlot];



(*Defining Pre DataSet from given mass values:*)
PreSUSYQCDDataSet = {{SUSYQCD, {MW2 -> WBosonMass^2, MZ2 -> ZBosonMass^2, Alfas -> AlfasValue, SW2 -> (1 - CWValue^2),CW2 -> CWValue^2, MGl -> x, MGl2 -> x^2, MSt22 -> y^2, MSt12 -> z^2, MT2 -> TopQuarkMass^2}}};

(*Normalization of all masses by MT and setting MSt12 = MT^2*)
SUSYQCDDataSet = ReplaceValuesInDataSet[PreSUSYQCDDataSet, {MGl2 -> MGl^2, MGl -> MGl, MSt22 -> MSt2^2, MSt12 -> 1,MT2 -> 1, MW2 -> PreviousValue/TopQuarkMass^2, MZ2 -> PreviousValue/TopQuarkMass^2}];

(*Evaluating DeltaC(SUSQCD) up to MSt2->y,MGl -> x and mixing angle thetax*)
DeltaCSUSYQCD[thetax_] := (DeltaCSUSYQCD[thetax] = PluginRealSfermionMixingMatrix[DoAllNumerics[{DeltaC[Gluino, Gammatt],DeltaC[Gluino, Ztt]}, SUSYQCDDataSet][[1, 2]]] /. theta[3, 3] -> thetax);



(*
CAUTION!
The labels values and label position have to beworked out by hand each time you change the input paramters!
This can be done for e.g. with LabelContourPlot[] function in a notebook. Use for example this command: (NOTEBOOK ONLY!)*)
(*
LabelContourPlot[Hold[ContourPlot[DeltaCSUSYQCD[0] /. {MGl -> x, MSt2 -> y}, {x, 1, 5}, {y, 1, 5}, Frame -> True, FrameLabel -> {Style["MG/MT", 21], Style["MSt2/MT", 21]}, ImageSize -> 500,LabelStyle -> Directive[Italic], FrameStyle -> 16]], LabelPrecision -> 1]
Set up labels by hand using CTRL+SHIFT+ALT+Click to add a lable and CTRL+ALT+Click to remove one.
$LabelList gives you a list like the ones below:
*)
LableListDeltaCSUSYQCDTheta0 = {{4.038`, 3.19`, 0.0014980670879006094`1.9999999999999991}, {2.982`, 3.185`, 0.0019793934617109107`2.000000000000001}, {2.241108`, 3.1939189999999997`, 0.0024944071007185096`1.9999999999999991}, {1.73`, 1.82`, 0.0029881245795741543`1.9999999999999998}, {1.342`, 3.19`, 0.0034731321468964805`2.000000000000001}, {1.352`, 1.06`, 0.0044847755894223537`2.0000000000000004}};
LableListDeltaCSUSYQCDThetaPiDiv4 = {{4.64`, 1.5050000000000001`, 0.0019767831316522076`1}, {3.9452849999999997`, 2.360354`, 0.0029881821673491261`1.000000000000001}, {3.343266`, 2.804922`, 0.0039998487797986409`1}, {2.889436`, 3.1939189999999997`, 0.0050066668630289754`1.000000000000001}, {2.481916`, 3.453251`, 0.0060130306347827168`1}, {1.87`, 3.94`, 0.0079566271887165346`1}, {1.36`, 4.49`, 0.009995586297606442`1.}};
LableListDeltaCSUSYQCDThetaPiDiv2 = {{4.464`, 4.285`, 0.0007975956902598897`2.000000000000001}, {3.472`, 3.61`, 0.0009960711056465781`1.9999999999999998}, {2.778294`, 2.916064`, 0.0011978212703001121`1.9999999999999998}, {2.287417`, 2.360354`, 0.0013999264270538106`2.000000000000001}, {1.537209`, 2.026928`, 0.0015905357181295703`2.0000000000000004}, {2.4078209999999998`, 1.443433`, 0.0020193336460215508`2.0000000000000004}};
LableListDeltaCSUSYQCDTheta3PiDiv4 = {{2.962`, 3.45`, -0.0019687573036776687`1.0000000000000004}, {3.500717`, 1.147054`, 0.001986232923443619`0.9999999999999999}, {4.399115`, 1.461957`, 0.0009980173896618101`1.0000000000000004}, {3.704478`, 2.925326`, -0.0009883974690012539`1.0000000000000009}, {2.296679`,3.823724`, -0.0030033931579958968`1.0000000000000004}, {1.806`, 4.1850000000000005`, -0.0040000134119998858`0.9999999999999993}, {1.379758`, 4.536885`, -0.005015660791499124`0.9999999999999991}};


(*This function draws each lable*)
TextFunction = Text[Framed[Style[#[[3]], Bold, 16, Italic, FontColor -> Darker[Blue]], FrameMargins -> 3, FrameStyle -> Black], {#[[1]], #[[2]]}, Background -> White] &;

(*Creating plots and merging them with labeles*)
DeltaCSUSYQCDTheta0 = Show[ContourPlot[DeltaCSUSYQCD[0] /. {MGl -> x, MSt2 -> y}, {x, 1, 5}, {y, 1, 5}, Frame -> True, FrameLabel -> {Style["\!\(\*SubscriptBox[\"m\", OverscriptBox[\"g\", \
\"~\"]]\)/\!\(\*SubscriptBox[\"m\", \"t\"]\)", 24], Style["\!\(\*SubscriptBox[\"m\", SubscriptBox[OverscriptBox[\"t\", \"~\"], \
\"2\"]]\)/\!\(\*SubscriptBox[\"m\", \"t\"]\)", 24]}, ImageSize -> 500,LabelStyle -> Directive[Italic], FrameStyle -> 16], Graphics[TextFunction /@ LableListDeltaCSUSYQCDTheta0]];

DeltaCSUSYQCDThetaPiDiv4 = Show[ContourPlot[DeltaCSUSYQCD[Pi/4] /. {MGl -> x, MSt2 -> y}, {x, 1, 5}, {y, 1, 5}, Frame -> True, FrameLabel -> {Style["\!\(\*SubscriptBox[\"m\", OverscriptBox[\"g\", \
\"~\"]]\)/\!\(\*SubscriptBox[\"m\", \"t\"]\)", 24], Style["\!\(\*SubscriptBox[\"m\", SubscriptBox[OverscriptBox[\"t\", \"~\"], \
\"2\"]]\)/\!\(\*SubscriptBox[\"m\", \"t\"]\)", 24]}, ImageSize -> 500,LabelStyle -> Directive[Italic], FrameStyle -> 16], Graphics[TextFunction /@ LableListDeltaCSUSYQCDThetaPiDiv4]];

DeltaCSUSYQCDThetaPiDiv2 = Show[ContourPlot[DeltaCSUSYQCD[Pi/2] /. {MGl -> x, MSt2 -> y}, {x, 1, 5}, {y, 1, 5}, Frame -> True, FrameLabel -> {Style["\!\(\*SubscriptBox[\"m\", OverscriptBox[\"g\", \
\"~\"]]\)/\!\(\*SubscriptBox[\"m\", \"t\"]\)", 24], Style["\!\(\*SubscriptBox[\"m\", SubscriptBox[OverscriptBox[\"t\", \"~\"], \
\"2\"]]\)/\!\(\*SubscriptBox[\"m\", \"t\"]\)", 24]}, ImageSize -> 500,LabelStyle -> Directive[Italic], FrameStyle -> 16], Graphics[TextFunction /@ LableListDeltaCSUSYQCDThetaPiDiv2]];

DeltaCSUSYQCDTheta3PiDiv4 = Show[ContourPlot[DeltaCSUSYQCD[3*Pi/4] /. {MGl -> x, MSt2 -> y}, {x, 1, 5}, {y, 1, 5}, Frame -> True, FrameLabel -> {Style["\!\(\*SubscriptBox[\"m\", OverscriptBox[\"g\", \
\"~\"]]\)/\!\(\*SubscriptBox[\"m\", \"t\"]\)", 24], Style["\!\(\*SubscriptBox[\"m\", SubscriptBox[OverscriptBox[\"t\", \"~\"], \
\"2\"]]\)/\!\(\*SubscriptBox[\"m\", \"t\"]\)", 24]}, ImageSize -> 500,LabelStyle -> Directive[Italic], FrameStyle -> 16], Graphics[TextFunction /@ LableListDeltaCSUSYQCDTheta3PiDiv4]];

Export[$TQPATDir <> "/examples/pics/GluinoDeltaMST1eqMTThetaeq0MTeq"<>ToString[TopQuarkMass]<>"Alfaseq"<>ToString[AlfasValue]<>".eps",DeltaCSUSYQCDTheta0];
Export[$TQPATDir <> "/examples/pics/GluinoDeltaMST1eqMTThetaeqPiDiv4MTeq"<>ToString[TopQuarkMass]<>"Alfaseq"<>ToString[AlfasValue]<>".eps",DeltaCSUSYQCDThetaPiDiv4];
Export[$TQPATDir <> "/examples/pics/GluinoDeltaMST1eqMTThetaeqPiDiv2MTeq"<>ToString[TopQuarkMass]<>"Alfaseq"<>ToString[AlfasValue]<>".eps",DeltaCSUSYQCDThetaPiDiv2];
Export[$TQPATDir <> "/examples/pics/GluinoDeltaMST1eqMTThetaeq3PiDiv4MTeq"<>ToString[TopQuarkMass]<>"Alfaseq"<>ToString[AlfasValue]<>".eps",DeltaCSUSYQCDTheta3PiDiv4];
